<?php
/*
 * Plugin Name: Engic Extension
 * Description: This plugin extends Visual Composer and adds custom post type capabilities.
 * Author: Euthemians Team
 * Author URI: http://euthemians.com
 * Version: 2.4.2
 * Text Domain: engic-extension
 */

if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! defined( 'ENGIC_EXT_VERSION' ) ) {
	define( 'ENGIC_EXT_VERSION', '2.4.2' );
}

if ( ! defined( 'ENGIC_EXT_PLUGIN_DIR_PATH' ) ) {
	define( 'ENGIC_EXT_PLUGIN_DIR_PATH', plugin_dir_path( __FILE__ ) );
}

if ( ! defined( 'ENGIC_EXT_PLUGIN_DIR_URL' ) ) {
	define( 'ENGIC_EXT_PLUGIN_DIR_URL', plugin_dir_url( __FILE__ ) );
}

if ( ! class_exists( 'Engic_Extension_Plugin' ) ) {

	class Engic_Extension_Plugin {

		/**
		 * @action plugins_loaded
		 * @return Engic_Extension_Plugin
		 * @static
		 */
		public static function init()
		{

			static $instance = false;

			if ( ! $instance ) {
				load_plugin_textdomain( 'engic-extension' , false , dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
				$instance = new Engic_Extension_Plugin;
			}
			return $instance;

		}

		/* Add Visual Composer Plugin*/
		private function __construct() {

			if ( is_user_logged_in() ) {
				add_action( 'admin_enqueue_scripts' , $this->marshal( 'engic_ext_vce_extension_add_scripts' ) );
			}
			add_action( 'wp_enqueue_scripts' , $this->marshal( 'engic_ext_vce_extension_add_front_end_scripts' ) );

			require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'includes/engic-ext-metaboxes.php';
			require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'includes/engic-ext-functions.php';
			require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'includes/engic-ext-add-param.php';
			require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'includes/engic-ext-shortcode-param.php';


			//Shortcodes
			if( function_exists( 'vc_lean_map' ) || function_exists( 'vc_map' ) ) {

				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_title.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_divider.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_list.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_button.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_quote.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_dropcap.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_slogan.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_callout.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_progress_bar.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_pricing_table.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_message_box.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_icon_box.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_image_text.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_media_box.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_single_image.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_gallery.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_slider.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_video.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_social.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_gmap.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_team.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_blog.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_portfolio.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_testimonial.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_counter.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_pie_chart.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_typed_text.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_expandable_info.php';
				
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_privacy_gtracking.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_privacy_gmaps.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_privacy_gfonts.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_privacy_video_embeds.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_privacy_required.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_privacy_policy_page_link.php';
				require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'shortcodes/engic_privacy_preferences_link.php';

			}

		}

		public function engic_extension_plugin() {
			$this->__construct();
		}


		public function engic_ext_vce_extension_add_scripts( $hook ) {
			wp_enqueue_style('engic-ext-vc-elements', ENGIC_EXT_PLUGIN_DIR_URL .'assets/css/engic-ext-vc-elements.css', array(), time(), 'all');
			wp_enqueue_style('engic-ext-vc-icon-box', ENGIC_EXT_PLUGIN_DIR_URL .'assets/css/engic-ext-icon-preview.css', array(), time(), 'all');
			wp_enqueue_style('engic-ext-vc-multi-checkbox', ENGIC_EXT_PLUGIN_DIR_URL .'assets/css/engic-ext-multi-checkbox.css', array(), time(), 'all');
			wp_enqueue_style('engic-eutf-simple-line-icons', ENGIC_EXT_PLUGIN_DIR_URL .'assets/css/simple-line-icons.css', array(), '2.2.3', 'all');
		}

		public function engic_ext_vce_extension_add_front_end_scripts() {
			wp_register_style( 'engic-eutf-simple-line-icons', ENGIC_EXT_PLUGIN_DIR_URL .'assets/css/simple-line-icons.css', array(), '2.2.3', 'all' );
		}



		public function marshal( $method_name ) {
			return array( &$this , $method_name );
		}
	}

	/**
	 * Initialize Extension Plugin
	 */
	add_action( 'init' , array( 'Engic_Extension_Plugin' , 'init' ), 12 );

	/**
	 * Initialize Custom Post Types
	 */
	function engic_ext_vce_rewrite_flush() {

		engic_ext_vce_register_custom_post_init();
		flush_rewrite_rules();
	}
	register_activation_hook( __FILE__, 'engic_ext_vce_rewrite_flush' );

	function engic_ext_vce_register_custom_post_init() {
		require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'includes/engic-portfolio-post-type.php';
		require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'includes/engic-testimonial-post-type.php';
	}
	add_action( 'init', 'engic_ext_vce_register_custom_post_init', 9 );

	function engic_ext_vce_body_class( $classes ){
		$ext_ver = 'eut-vce-ver-' . ENGIC_EXT_VERSION;
		return array_merge( $classes, array( $ext_ver ) );
	}
	add_filter( 'body_class', 'engic_ext_vce_body_class' );
	
	require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'includes/engic-ext-global-functions.php';
	
	/**
	 * Include Widgets
	 */	
	function engic_ext_register_widgets() {
		require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'widgets/engic-eutf-widget-social.php';
		require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'widgets/engic-eutf-widget-latest-posts.php';
		require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'widgets/engic-eutf-widget-latest-comments.php';
		require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'widgets/engic-eutf-widget-latest-portfolio.php';
		require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'widgets/engic-eutf-widget-contact-info.php';
		register_widget( 'Engic_Ext_Widget_Latest_Portfolio' );
		register_widget( 'Engic_Ext_Widget_Latest_Posts' );
		register_widget( 'Engic_ext_Widget_Social' );
		register_widget( 'Engic_Ext_Widget_Contact_Info' );
		register_widget( 'Engic_Ext_Widget_Latest_Comments' );
	}
	add_action( 'widgets_init', 'engic_ext_register_widgets' );	
	
	/**
	 *Admin Menu
	 */
	require_once ENGIC_EXT_PLUGIN_DIR_PATH . 'includes/admin/engic-ext-admin-functions.php';		
}

//Omit closing PHP tag to avoid accidental whitespace output errors.
