<?php
/*
*	Testimonial Post Type Registration
*
* 	@author		Euthemians Team
* 	@URI		http://euthemians.com
*/

if ( ! class_exists( 'Engic_Testimonial_Post_Type' ) ) {
	class Engic_Testimonial_Post_Type {

		function __construct() {

			// Adds the testimonial post type and taxonomies
			$this->engic_testimonial_init();

			// Manage Columns for testimonial overview
			add_filter( 'manage_edit-testimonial_columns',  array( &$this, 'engic_testimonial_edit_columns' ) );
			add_action( 'manage_posts_custom_column', array( &$this, 'engic_testimonial_custom_columns' ), 10, 2 );

		}

		function engic_testimonial_init() {


			$labels = array(
				'name' => esc_html_x( 'Testimonial Items', 'Testimonial General Name', 'engic-extension' ),
				'singular_name' => esc_html_x( 'Testimonial Item', 'Testimonial Singular Name', 'engic-extension' ),
				'add_new' => esc_html__( 'Add New', 'engic-extension' ),
				'add_new_item' => esc_html__( 'Add New Testimonial Item', 'engic-extension' ),
				'edit_item' => esc_html__( 'Edit Testimonial Item', 'engic-extension' ),
				'new_item' => esc_html__( 'New Testimonial Item', 'engic-extension' ),
				'view_item' => esc_html__( 'View Testimonial Item', 'engic-extension' ),
				'search_items' => esc_html__( 'Search Testimonial Items', 'engic-extension' ),
				'not_found' =>  esc_html__( 'No Testimonial Items found', 'engic-extension' ),
				'not_found_in_trash' => esc_html__( 'No Testimonial Items found in Trash', 'engic-extension' ),
				'parent_item_colon' => '',
			);

			$category_labels = array(
				'name' => esc_html__( 'Testimonial Categories', 'engic-extension' ),
				'singular_name' => esc_html__( 'Testimonial Category', 'engic-extension' ),
				'search_items' => esc_html__( 'Search Testimonial Categories', 'engic-extension' ),
				'all_items' => esc_html__( 'All Testimonial Categories', 'engic-extension' ),
				'parent_item' => esc_html__( 'Parent Testimonial Category', 'engic-extension' ),
				'parent_item_colon' => esc_html__( 'Parent Testimonial Category:', 'engic-extension' ),
				'edit_item' => esc_html__( 'Edit Testimonial Category', 'engic-extension' ),
				'update_item' => esc_html__( 'Update Testimonial Category', 'engic-extension' ),
				'add_new_item' => esc_html__( 'Add New Testimonial Category', 'engic-extension' ),
				'new_item_name' => esc_html__( 'New Testimonial Category Name', 'engic-extension' ),
			);

			$args = array(
				'labels' => $labels,
				'public' => true,
				'publicly_queryable' => true,
				'show_ui' => true,
				'query_var' => true,
				'rewrite' => true,
				'capability_type' => 'post',
				'hierarchical' => false,
				'menu_position' => 5,
				'menu_icon' => 'dashicons-testimonial',
				'supports' => array( 'title', 'editor', 'author' ),
				'rewrite' => array( 'slug' => 'testimonial', 'with_front' => false ),
			  );

			register_post_type( 'testimonial' , $args );

			register_taxonomy(
				'testimonial_category',
				array( 'testimonial' ),
				array(
					'hierarchical' => true,
					'label' => esc_html__( 'Testimonial Categories', 'engic-extension' ),
					'labels' => $category_labels,
					'show_in_nav_menus' => false,
					'show_tagcloud' => false,
					'rewrite' => true,
				)
			);
			register_taxonomy_for_object_type( 'testimonial_category', 'testimonial' );

		}

		function engic_testimonial_edit_columns( $columns ) {

			$columns['cb'] = "<input type=\"checkbox\" />";
			$columns['title'] = esc_html__( 'Title', 'engic-extension' );
			$columns['author'] = esc_html__( 'Author', 'engic-extension' );
			$columns['testimonial_category'] = esc_html__( 'Testimonial Categories', 'engic-extension' );
			$columns['date'] = esc_html__( 'Date', 'engic-extension' );

			return $columns;
		}

		function engic_testimonial_custom_columns( $column, $post_id ) {

			switch ( $column ) {
				case 'testimonial_category':
					echo get_the_term_list( $post_id, 'testimonial_category', '', ', ','' );
				break;
			}
		}

	}
	new Engic_Testimonial_Post_Type;
}

//Omit closing PHP tag to avoid accidental whitespace output errors.
