<?php
/**
 * Callout Shortcode
 */

if( !function_exists( 'engic_ext_calout_shortcode' ) ) {

	function engic_ext_calout_shortcode( $atts, $content ) {

		$output = $button = $data = $class_leader = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'title' => '',
					'heading' => 'h3',
					'button_text' => '',
					'button_link' => '',
					'button_type' => 'simple',
					'btn_position' => 'btn-right',
					'button_size' => 'medium',
					'button_color' => 'primary-1',
					'button_shape' => 'square',
					'button_class' => '',
					'leader_text' => '',
					'animation' => '',
					'animation_delay' => '200',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$atts
			)
		);

		if ( !empty( $animation ) ) {
			$animation = 'eut-' . $animation;
		}

		if ( 'yes' == $leader_text ) {
			$class_leader = 'eut-leader-text';
		}

		//Button
		$button = engic_ext_vce_get_button( $button_text, $button_link, $button_type, $button_size, $button_color, $button_shape, $button_class );

		$callout_classes = array( 'eut-element', 'eut-callout' );

		if ( !empty( $animation ) ) {
			array_push( $callout_classes, 'eut-animated-item' );
			array_push( $callout_classes, $animation);
			$data = ' data-delay="' . esc_attr( $animation_delay ) . '"';
		}

		if ( !empty ( $el_class ) ) {
			array_push( $callout_classes, $el_class);
		}

		array_push( $callout_classes, 'eut-' . $btn_position );

		$callout_class_string = implode( ' ', $callout_classes );

		$style = engic_ext_vce_build_margin_bottom_style( $margin_bottom );

		$output .= '<div class="' . esc_attr( $callout_class_string ) . '" style="' . $style . '">';
		$output .= '  <div class="eut-callout-wrapper">';
		if ( !empty( $title ) ) {
			$output .= '<' . $heading . ' class="eut-callout-content">' . $title . '</' . $heading . '>';
		}
		if ( !empty( $content ) ) {
		$output .= '    <p class="'. esc_attr( $class_leader ) . '">' . $content. '</p>';
		}
		$output .= '  </div>';
		$output .= '  <div class="eut-button-wrapper">';
		$output .= $button;
		$output .= '  </div>';
		$output .= '</div>';

		return $output;
	}
	add_shortcode( 'engic_callout', 'engic_ext_calout_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

if( !function_exists( 'engic_ext_callout_shortcode_params' ) ) {
	function engic_ext_callout_shortcode_params( $tag ) {
		return array(
			"name" => esc_html__( "Callout", "engic-extension" ),
			"description" => esc_html__( "Two different styles for interesting callouts", "engic-extension" ),
			"base" => $tag,
			"class" => "",
			"icon"      => "icon-wpb-eut-callout",
			"category" => esc_html__( "Content", "js_composer" ),
			"params" => array(
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Title", "engic-extension" ),
					"param_name" => "title",
					"value" => "",
					"description" => esc_html__( "Enter your title.", "engic-extension" ),
					"admin_label" => true,
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Heading", "engic-extension" ),
					"param_name" => "heading",
					"admin_label" => true,
					"value" => array( 'h1', 'h2', 'h3', 'h4' , 'h5', 'h6' ),
					"std" => "h3",
					"description" => esc_html__( "Heading size", "engic-extension" ),
				),
				array(
					"type" => "textarea",
					"heading" => esc_html__( "Text", "engic-extension" ),
					"param_name" => "content",
					"value" => "",
					"description" => esc_html__( "Enter your text.", "engic-extension" ),
					"dependency" => Array( 'element' => "callout_style", 'value' => array( '1' ) ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Leader Text", "engic-extension" ),
					"param_name" => "leader_text",
					"description" => esc_html__( "If selected, text will be shown as leader", "engic-extension" ),
					"value" => Array( esc_html__( "Make text leader", "engic-extension" ) => 'yes' ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Button Position", "engic-extension" ),
					"param_name" => "btn_position",
					"value" => array(
						esc_html__( "Right", "engic-extension" ) => 'btn-right',
						esc_html__( "Bottom", "engic-extension" ) => 'btn-bottom',
					),
					"description" => esc_html__( "Select the position of the button.", "engic-extension" ),
					"group" => esc_html__( "Button", "engic-extension" ),
				),
				engic_ext_vce_add_button_type(),
				engic_ext_vce_add_button_color(),
				engic_ext_vce_add_button_text(),
				engic_ext_vce_add_button_size(),
				engic_ext_vce_add_button_shape(),
				engic_ext_vce_add_button_link(),
				engic_ext_vce_add_button_class(),
				engic_ext_vce_add_animation(),
				engic_ext_vce_add_animation_delay(),
				engic_ext_vce_add_margin_bottom(),
				engic_ext_vce_add_el_class(),
			),
		);
	}
}

if( function_exists( 'vc_lean_map' ) ) {
	vc_lean_map( 'engic_callout', 'engic_ext_callout_shortcode_params' );
} else if( function_exists( 'vc_map' ) ) {
	$attributes = engic_ext_callout_shortcode_params( 'engic_callout' );
	vc_map( $attributes );
}

//Omit closing PHP tag to avoid accidental whitespace output errors.