<?php
/**
 * Gallery Shortcode
 */

if( !function_exists( 'engic_ext_gallery_shortcode' ) ) {

	function engic_ext_gallery_shortcode( $attr, $content ) {

		$output = $start_block = $end_block = $item_class = $class_fullwidth = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'ids' => '',
					'gallery_type' => 'grid',
					'grid_image_mode' => 'square',
					'masonry_image_mode' => '',
					'carousel_image_mode' => 'landscape',
					'carousel_popup' => '',
					'link_mode' => 'popup',
					'custom_links' => '',
					'custom_links_target' => '_self',
					'columns' => '3',
					'columns_tablet_landscape' => '2',
					'columns_tablet_portrait' => '2',
					'columns_mobile' => '1',
					'item_gutter' => 'yes',
					'gutter_size' => '40',
					'hide_image_title' => '',
					'hide_image_caption' => '',
					'zoom_effect' => 'none',
					'overlay_color' => 'light',
					'overlay_opacity' => '90',
					'items_per_page' => '4',
					'slideshow_speed' => '3000',
					'auto_play' => 'yes',
					'navigation_type' => '1',
					'navigation_color' => 'dark',
					'pause_hover' => 'no',
					'animation' => 'fadeInUp',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$attr
			)
		);

		if ( !empty( $animation ) ) {
			$animation = 'eut-' . $animation;
		}

		$attachments = explode( ",", $ids );

		if ( empty( $attachments ) ) {
			return '';
		}

		//Gallery Classes
		$gallery_classes = array( 'eut-element' );

		if ( 'custom_link' == $link_mode ) {
			$custom_links = vc_value_from_safe( $custom_links );
			$custom_links = explode( ',', $custom_links );
		} elseif ( 'popup' == $link_mode ) {
			array_push( $gallery_classes, 'eut-gallery-popup' );
		}

		if ( !empty( $el_class ) ) {
			array_push( $gallery_classes, $el_class);
		}



		$style = engic_ext_vce_build_margin_bottom_style( $margin_bottom );

		$data_string = '';

		switch( $gallery_type ) {
			case 'masonry':
				$data_string = ' data-columns="' . esc_attr( $columns ) . '" data-columns-tablet-landscape="' . esc_attr( $columns_tablet_landscape ) . '" data-columns-tablet-portrait="' . esc_attr( $columns_tablet_portrait ) . '" data-columns-mobile="' . esc_attr( $columns_mobile ) . '" data-layout="masonry"';
				array_push( $gallery_classes, 'eut-isotope' );
				array_push( $gallery_classes, 'eut-gallery' );
				if ( 'yes' == $item_gutter ) {
					array_push( $gallery_classes, 'eut-with-gap' );
					$data_string .= ' data-gutter-size="' . esc_attr( $gutter_size ) . '"';
				}
				break;
			case 'carousel':
				$data_string = ' data-items="' . esc_attr( $items_per_page ) . '" data-slider-autoplay="' . esc_attr( $auto_play ) . '" data-slider-speed="' . esc_attr( $slideshow_speed ) . '" data-slider-pause="' . esc_attr( $pause_hover ) . '"';
				array_push( $gallery_classes, 'eut-carousel-wrapper' );
				if ( 'yes' == $item_gutter ) {
					array_push( $gallery_classes, 'eut-with-gap' );
				}
				break;
			case 'grid':
			default:
				$data_string = ' data-columns="' . esc_attr( $columns ) . '" data-columns-tablet-landscape="' . esc_attr( $columns_tablet_landscape ) . '" data-columns-tablet-portrait="' . esc_attr( $columns_tablet_portrait ) . '" data-columns-mobile="' . esc_attr( $columns_mobile ) . '" data-layout="fitRows"';
				array_push( $gallery_classes, 'eut-isotope' );
				array_push( $gallery_classes, 'eut-gallery' );
				if ( 'yes' == $item_gutter ) {
					array_push( $gallery_classes, 'eut-with-gap' );
					$data_string .= ' data-gutter-size="' . esc_attr( $gutter_size ) . '"';
				}
				break;
		}
		$gallery_class_string = implode( ' ', $gallery_classes );

		if ( 'carousel' == $gallery_type ) {
			//Gallery Output ( carousel)

			if( 'square' == $carousel_image_mode ) {
				$image_size = 'engic-eutf-small-square';
			} elseif( 'portrait' == $carousel_image_mode ) {
				$image_size = 'engic-eutf-small-rect-vertical';
			} else {
				$image_size = 'engic-eutf-small-rect-horizontal';
			}


			$output .= '<div class="' . $gallery_class_string . '" style="' . $style . '">';

			if ( 0 != $navigation_type ) {

				$output .= '<div class="eut-carousel-navigation eut-' . esc_attr( $navigation_color ) . '" data-navigation-type="' . esc_attr( $navigation_type ) . '">';
				$output .= '	<div class="eut-carousel-buttons">';
				$output .= '		<div class="eut-carousel-prev eut-icon-nav-left"></div>';
				$output .= '		<div class="eut-carousel-next eut-icon-nav-right"></div>';
				$output .= '	</div>';
				$output .= '</div>';

			}
			$output .= '	<div class="eut-carousel eut-gallery-popup eut-carousel-element ' . esc_attr( $el_class ) . '"' . $data_string . '>

			';

				foreach ( $attachments as $id ) {
					$full_src = wp_get_attachment_image_src( $id, 'engic-eutf-fullscreen' );
					if ( ! $full_src ) {
						continue;
					}
					$image_title = get_post_field( 'post_title', $id );
					$caption = get_post_field( 'post_excerpt', $id );
					$link_data = '';
					if ( !empty( $image_title ) && 'yes' != $hide_image_title  ) {
						$link_data .= ' data-title="' . esc_attr( $image_title ) . '"';
					}
					if ( !empty( $caption ) && 'yes' != $hide_image_caption ) {
						$link_data .= ' data-desc="' . esc_attr( $caption ) . '"';
					}

					$output .= '<div class="eut-carousel-item">';
					if ( 'yes' == $carousel_popup ) {
					$output .= '  <a href="' . esc_url( $full_src[0] ) . '" ' . $link_data . '>';
					}
					$output .= '	<figure class="eut-image-hover">';
					$output .= '		<div class="eut-media">';
					$output .= wp_get_attachment_image( $id, $image_size );
					$output .= '		</div>';
					$output .= '	</figure>';
					if ( 'yes' == $carousel_popup ) {
					$output .= '  </a>';
					}
					$output .= '</div>';

				}
			$output .= '	</div>';
			$output .= '</div>';
		} else {
			//Gallery Output ( grid / masonry)
			$output .= '<div class="' . esc_attr( $gallery_class_string ) . '" style="' . $style . '"' . $data_string . '>';
			$output .= '  <div class="eut-isotope-container">';

			$gallery_index = 0;
			$i = -1;
			$image_size = 'engic-eutf-small-square';
			$image_size_class = '';

			foreach ( $attachments as $id ) {
				$gallery_index++;
				$i++;

				if ( 'masonry' == $gallery_type ) {

					if ( empty( $masonry_image_mode ) ) {
						$engic_ext_masonry_data = engic_ext_vce_get_masonry_data( $gallery_index, $columns );
						$image_size_class = ' ' . $engic_ext_masonry_data['class'];
						$image_size = $engic_ext_masonry_data['image_size'];
					} else {
						$image_size = 'large';
					}

				} else {
					//Grid - Default
					if ( 'resize' == $grid_image_mode ) {
						$image_size = 'large';
					} elseif( 'square' == $grid_image_mode ) {
						$image_size = 'engic-eutf-small-square';
					} elseif( 'portrait' == $grid_image_mode ) {
						$image_size = 'engic-eutf-small-rect-vertical';
					} else {
						$image_size = 'engic-eutf-small-rect-horizontal';
					}
				}


				$image_link_href =  wp_get_attachment_url( $id );

				$full_src = wp_get_attachment_image_src( $id, 'engic-eutf-fullscreen' );
				if ( ! $full_src ) {
					continue;
				}
				$image_title = get_post_field( 'post_title', $id );
				$caption = get_post_field( 'post_excerpt', $id );

				$output .= '<div class="eut-isotope-item ' . $image_size_class . '">';
				$output .= '  <div class="eut-isotope-item-inner ' . esc_attr( $animation ) . '">';

				if ( 'popup' ==  $link_mode ) {
					$output .= '<a href="' . esc_url( $full_src[0] ) . '">';
				} elseif ( 'custom_link' == $link_mode && isset( $custom_links[ $i ] ) && !empty(  $custom_links[ $i ] )  ) {
					$output .= '<a href="' . esc_url( $custom_links[ $i ] ) . '" target="' . esc_attr( $custom_links_target ) . '">';
				}

				$output .= '      <figure class="eut-image-hover eut-zoom-' . $zoom_effect . '">';
				$output .= '        <div class="eut-media eut-' . $overlay_color . '-overlay eut-opacity-' . $overlay_opacity . '">';
				$output .= wp_get_attachment_image( $id, $image_size );
				$output .= '        </div>';
				$output .= '        <figcaption>';

					if ( !empty( $image_title ) && 'yes' != $hide_image_title  ) {
						$output .= '<h5 class="eut-title eut-' . esc_attr( $overlay_color ) . '">' . wptexturize( $image_title ) . '</h5>';
					}

					if ( !empty( $caption ) && 'yes' != $hide_image_caption ) {
						$output .= '<span class="eut-caption eut-' . esc_attr( $overlay_color ) . '">' . wptexturize( $caption ) . '</span>';
					}

				$output .= '        </figcaption>';
				$output .= '      </figure>';
				if ( 'popup' ==  $link_mode ) {
					$output .= '</a>';
				} elseif ( 'custom_link' == $link_mode && isset( $custom_links[ $i ] ) && !empty(  $custom_links[ $i ] )  ) {
					$output .= '</a>';
				}
				$output .= '  </div>';
				$output .= '</div>';

			}

			$output .= '  </div>';
			$output .= '</div>';
		}


		return $output;

	}
	add_shortcode( 'engic_gallery', 'engic_ext_gallery_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

if( !function_exists( 'engic_ext_gallery_shortcode_params' ) ) {
	function engic_ext_gallery_shortcode_params( $tag ) {
		return array(
			"name" => esc_html__( "Gallery", "engic-extension" ),
			"description" => esc_html__( "Numerous styles, multiple columns for galleries", "engic-extension" ),
			"base" => $tag,
			"class" => "",
			"icon"      => "icon-wpb-eut-gallery",
			"category" => esc_html__( "Content", "js_composer" ),
			"params" => array(
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Gallery type", "engic-extension" ),
					"param_name" => "gallery_type",
					"value" => array(
						esc_html__( "Grid", "engic-extension" ) => 'grid',
						esc_html__( "Masonry", "engic-extension" ) => 'masonry',
						esc_html__( "Carousel", "engic-extension" ) => 'carousel',
					),
					"description" => esc_html__( "Select your gallery type.", "engic-extension" ),
					"admin_label" => true,
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Grid Image Mode", "engic-extension" ),
					"param_name" => "grid_image_mode",
					'value' => array(
						esc_html__( 'Square Crop', 'engic-extension' ) => 'square',
						esc_html__( 'Landscape Crop', 'engic-extension' ) => 'landscape',
						esc_html__( 'Portrait Crop', 'engic-extension' ) => 'portrait',
						esc_html__( 'Resize ( Large )', 'engic-extension' ) => 'resize',
					),
					'std' => 'square',
					"description" => esc_html__( "Select your Grid Image Mode.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'grid' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Masonry Image Mode", "engic-extension" ),
					"param_name" => "masonry_image_mode",
					'value' => array(
						esc_html__( 'Auto', 'engic-extension' ) => '',
						esc_html__( 'Resize ( Large )', 'engic-extension' ) => 'resize',
					),
					'std' => 'square',
					"description" => esc_html__( "Select your Masonry Image Mode.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Carousel Image Mode", "engic-extension" ),
					"param_name" => "carousel_image_mode",
					'value' => array(
						esc_html__( 'Square Crop', 'engic-extension' ) => 'square',
						esc_html__( 'Landscape Crop', 'engic-extension' ) => 'landscape',
						esc_html__( 'Portrait Crop', 'engic-extension' ) => 'portrait',
					),
					'std' => 'landscape',
					"description" => esc_html__( "Select your Carousel Image Mode.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'carousel' ) ),
				),
				array(
					"type"			=> "attach_images",
					"admin_label"	=> true,
					"class"			=> "",
					"heading"		=> esc_html__( "Attach Images", "engic-extension" ),
					"param_name"	=> "ids",
					"value" => '',
					"description"	=> esc_html__( "Select your gallery images.", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => __( "Link Mode", "engic-extension" ),
					"param_name" => "link_mode",
					'value' => array(
						__( 'Gallery Popup', 'engic-extension' ) => 'popup',
						__( 'None', 'engic-extension' ) => 'none',
						__( "Custom Link", "engic-extension" ) => 'custom_link',
					),
					"description" => __( "Select your gallery link mode.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'grid', 'masonry' ) ),
					"std" => 'popup',
				),
				array(
					'type' => 'exploded_textarea_safe',
					'heading' => __( 'Custom links', 'engic-extension' ),
					'param_name' => 'custom_links',
					'description' => __( 'Enter links for each slide (Note: divide links with linebreaks (Enter)).', 'engic-extension' ),
					'dependency' => array(
						'element' => 'link_mode',
						'value' => array( 'custom_link' ),
					),
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Custom link target', 'engic-extension' ),
					'param_name' => 'custom_links_target',
					'description' => __( 'Select where to open custom links.', 'engic-extension' ),
					'dependency' => array(
						'element' => 'link_mode',
						'value' => array( 'custom_link' ),
					),
					"value" => array(
						__( "Same Window", "engic-extension" ) => '_self',
						__( "New Window", "engic-extension" ) => '_blank',
					),
				),
				//Gallery ( grid /masonry )
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Columns", "engic-extension" ),
					"param_name" => "columns",
					"value" => array( '2', '3', '4', '5' ),
					"std" => '3',
					"description" => esc_html__( "Select number of columns.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Tablet Landscape Columns", "engic-extension" ),
					"param_name" => "columns_tablet_landscape",
					"value" => array( '2', '3', '4', '5' ),
					"std" => '2',
					"description" => esc_html__( "Select responsive column on tablet devices, landscape orientation.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Tablet Portrait Columns", "engic-extension" ),
					"param_name" => "columns_tablet_portrait",
					"value" => array( '2', '3', '4', '5' ),
					"std" => '2',
					"description" => esc_html__( "Select responsive column on tablet devices, portrait orientation.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Mobile Columns", "engic-extension" ),
					"param_name" => "columns_mobile",
					"value" => array( '1', '2', '3' ),
					"std" => '1',
					"description" => esc_html__( "Select responsive column on mobile devices.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Gutter between images", "engic-extension" ),
					"param_name" => "item_gutter",
					"value" => array(
						esc_html__( "Yes", "engic-extension" ) => 'yes',
						esc_html__( "No", "engic-extension" ) => 'no',
					),
					"description" => esc_html__( "Add gutter among images.", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Gutter Size", "engic-extension" ),
					"param_name" => "gutter_size",
					"value" => '40',
					"dependency" => array( 'element' => "item_gutter", 'value' => array( 'yes' ) ),
					"description" => esc_html__( "Note: Available only for Grid and Masonry", "engic-extension" ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Hide Image Title", "engic-extension" ),
					"param_name" => "hide_image_title",
					"value" => Array( esc_html__( "If selected, image title will be hidden", "engic-extension" ) => 'yes' ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Hide Image Caption", "engic-extension" ),
					"param_name" => "hide_image_caption",
					"value" => Array( esc_html__( "If selected, image caption will be hidden", "engic-extension" ) => 'yes' ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Image Zoom Effect", "engic-extension" ),
					"param_name" => "zoom_effect",
					"value" => array(
						esc_html__( "Zoom In", "engic-extension" ) => 'in',
						esc_html__( "Zoom Out", "engic-extension" ) => 'out',
						esc_html__( "None", "engic-extension" ) => 'none',
					),
					"description" => esc_html__( "Choose the image zoom effect.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'grid', 'masonry' ) ),
					'std' => 'none',
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Overlay Color", "engic-extension" ),
					"param_name" => "overlay_color",
					"value" => array(
						esc_html__( "Light", "engic-extension" ) => 'light',
						esc_html__( "Dark", "engic-extension" ) => 'dark',
						esc_html__( "Primary 1", "engic-extension" ) => 'primary-1',
						esc_html__( "Primary 2", "engic-extension" ) => 'primary-2',
						esc_html__( "Primary 3", "engic-extension" ) => 'primary-3',
						esc_html__( "Primary 4", "engic-extension" ) => 'primary-4',
						esc_html__( "Primary 5", "engic-extension" ) => 'primary-5',
					),
					"description" => esc_html__( "Choose the image color overlay.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Overlay Opacity", "engic-extension" ),
					"param_name" => "overlay_opacity",
					"value" => array( '0', '10', '20', '30', '40', '50', '60', '70', '80', '90', '100' ),
					"std" => '90',
					"description" => esc_html__( "Choose the opacity for the overlay.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__("CSS Animation", "engic-extension"),
					"param_name" => "animation",
					"value" => array(
						esc_html__( "No", "engic-extension" ) => '',
						esc_html__( "Fade In Up", "engic-extension" ) => "fadeInUp",
					),
					"std" => "fadeInUp",
					"description" => esc_html__("Select type of animation if you want this element to be animated when it enters into the browsers viewport. Note: Works only in modern browsers.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'grid', 'masonry' ) ),
				),
				//Gallery ( carousel )
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Items per page", "engic-extension" ),
					"param_name" => "items_per_page",
					"value" => array( '3', '4', '5' ),
					"description" => esc_html__( "Number of images per page", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'carousel' ) ),
					"std" => "4",
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Carousel Image Popup", "engic-extension" ),
					"param_name" => "carousel_popup",
					"value" => Array( esc_html__( "Enable carousel image popup", "engic-extension" ) => 'yes' ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'carousel' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Autoplay", "engic-extension" ),
					"param_name" => "auto_play",
					"value" => array(
						esc_html__( "Yes", "engic-extension" ) => 'yes',
						esc_html__( "No", "engic-extension" ) => 'no',
					),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'carousel' ) ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Slideshow Speed", "engic-extension" ),
					"param_name" => "slideshow_speed",
					"value" => '3000',
					"description" => esc_html__( "Slideshow Speed in ms.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'carousel' ) ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Pause on Hover", "engic-extension" ),
					"param_name" => "pause_hover",
					"value" => Array( esc_html__( "If selected, carousel will be paused on hover", "engic-extension" ) => 'yes' ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'carousel' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Navigation Type", "engic-extension" ),
					"param_name" => "navigation_type",
					'value' => array(
						esc_html__( 'Style 1' , 'engic-extension' ) => '1',
						esc_html__( 'Style 2' , 'engic-extension' ) => '2',
						esc_html__( 'Style 3' , 'engic-extension' ) => '3',
						esc_html__( 'Style 4' , 'engic-extension' ) => '4',
						esc_html__( 'No Navigation' , 'engic-extension' ) => '0',
					),
					"description" => esc_html__( "Select your Navigation type.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'carousel' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Navigation Color", "engic-extension" ),
					"param_name" => "navigation_color",
					'value' => array(
						esc_html__( 'Dark' , 'engic-extension' ) => 'dark',
						esc_html__( 'Light' , 'engic-extension' ) => 'light',
					),
					"description" => esc_html__( "Select the background Navigation color.", "engic-extension" ),
					"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'carousel' ) ),
				),
				engic_ext_vce_add_margin_bottom(),
				engic_ext_vce_add_el_class(),
			),
		);
	}
}

if( function_exists( 'vc_lean_map' ) ) {
	vc_lean_map( 'engic_gallery', 'engic_ext_gallery_shortcode_params' );
} else if( function_exists( 'vc_map' ) ) {
	$attributes = engic_ext_gallery_shortcode_params( 'engic_gallery' );
	vc_map( $attributes );
}

//Omit closing PHP tag to avoid accidental whitespace output errors.