<?php
/**
 * Image Text Shortcode
 */

if( !function_exists( 'engic_ext_image_text_shortcode' ) ) {

	function engic_ext_image_text_shortcode( $atts, $content ) {

		$output = $output_image = $data = $retina_data = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'title' => '',
					'heading' => 'h3',
					'image' => '',
					'retina_image' => '',
					'image_align' => 'left',
					'video_popup' => '',
					'video_link' => '',
					'read_more_title' => '',
					'read_more_link' => '',
					'read_more_class' => '',
					'animation' => '',
					'animation_delay' => '200',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$atts
			)
		);

		if ( !empty( $animation ) ) {
			$animation = 'eut-' . $animation;
		}

		if ( !empty( $read_more_link ) ){
			$href = vc_build_link( $read_more_link );
			$url = $href['url'];
			if ( !empty( $href['target'] ) ){
				$target = $href['target'];
			} else {
				$target= "_self";
			}
		} else {
			$url = "#";
			$target= "_self";
		}
		$target = trim( $target );

		$style = engic_ext_vce_build_margin_bottom_style( $margin_bottom );

		$image_text_classes = array( 'eut-element', 'eut-image-text' );

		if ( !empty( $animation ) ) {
			array_push( $image_text_classes, 'eut-animated-item' );
			array_push( $image_text_classes, $animation);
			$data = ' data-delay="' . esc_attr( $animation_delay ) . '"';
		}
		if ( !empty( $el_class ) ) {
			array_push( $image_text_classes, $el_class);
		}
		$image_text_class_string = implode( ' ', $image_text_classes );


		$output .= '<div class="' . esc_attr( $image_text_class_string ) . '" style="' . $style . '"' . $data . '>';
		if ( !empty( $image ) ) {
			$image_html = '';
			$img_id = preg_replace('/[^\d]/', '', $image);
			$img_src = wp_get_attachment_image_src( $img_id, 'full' );
			if ( $img_src ) {
				$img_url = $img_src[0];
				$image_srcset = '';
				if ( !empty( $retina_image ) ) {
					$img_retina_id = preg_replace('/[^\d]/', '', $retina_image);
					$img_retina_src = wp_get_attachment_image_src( $img_retina_id, 'full' );
					if ( $img_retina_src ) {
						$retina_url = $img_retina_src[0];
						$image_srcset = esc_url( $img_url ) . ' 1x,' . esc_url( $retina_url ) . ' 2x';
						$image_html = wp_get_attachment_image( $img_id, 'full' , '', array( 'srcset'=> $image_srcset ) );
					} else {
						$image_html = wp_get_attachment_image( $img_id, 'full' );
					}
				} else {
					$image_html = wp_get_attachment_image( $img_id, 'full' );
				}
			}

			if ( 'yes' == $video_popup && !empty( $video_link ) ) {
				$output_image .= '<div class="eut-image">';
				$output_image .= '<a class="eut-vimeo-popup eut-icon-video" href="' . esc_url( $video_link ) . '">';
				$output_image .= $image_html;
				$output_image .= '</a>';
				$output_image .= '</div>';
			} else {
				$output_image .= '<div class="eut-image">';
				$output_image .= $image_html;
				$output_image .= '</div>';
			}


			if ( 'left' == $image_align ) {
				$output .= $output_image;
			}

			$output .= '  <div class="eut-content eut-align-' . esc_attr( $image_align ) . '">';
			if ( !empty( $title ) ) {
			$output .= '<' . $heading . '>' . $title. '</' . $heading . '>';
			}
			if ( !empty( $content ) ) {
			$output .= '  <p>' . do_shortcode( $content ) . '</p>';
			}
			if ( !empty( $read_more_title ) && !empty( $url ) ) {
				$output .= '    <a href="' . esc_url( $url ) . '" target="' . $target . '" class="eut-read-more ' . esc_attr( $read_more_class ) . '">';
				$output .=  $read_more_title ;
				$output .= '</a>';
			}
			$output .= '  </div>';


			if ( 'right' == $image_align ) {
				$output .= $output_image;
			}

		}
		$output .= '</div>';


		return $output;
	}
	add_shortcode( 'engic_image_text', 'engic_ext_image_text_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

if( !function_exists( 'engic_ext_image_text_shortcode_params' ) ) {
	function engic_ext_image_text_shortcode_params( $tag ) {
		return array(
			"name" => esc_html__( "Image Text", "engic-extension" ),
			"description" => esc_html__( "Combine image or video with text and button", "engic-extension" ),
			"base" => $tag,
			"class" => "",
			"icon"      => "icon-wpb-eut-image-text",
			"category" => esc_html__( "Content", "js_composer" ),
			"params" => array(
				array(
					"type" => "attach_image",
					"heading" => esc_html__( "Image", "engic-extension" ),
					"param_name" => "image",
					"value" => '',
					"description" => esc_html__( "Select an image.", "engic-extension" ),
				),
				array(
					"type" => "attach_image",
					"heading" => esc_html__( "Retina Image", "engic-extension" ),
					"param_name" => "retina_image",
					"value" => '',
					"description" => esc_html__( "Select a 2x image.", "engic-extension" ),
				),
				array(
					"type" => 'dropdown',
					"heading" => esc_html__( "Image align", "engic-extension" ),
					"param_name" => "image_align",
					"description" => esc_html__( "Set the alignment of your image", "engic-extension" ),
					"value" => array(
						esc_html__( "Left", "engic-extension" ) => 'left',
						esc_html__( "Right", "engic-extension" ) => 'right',
					),
				),
				array(
					"type" => 'dropdown',
					"heading" => esc_html__( "Video popup", "engic-extension" ),
					"param_name" => "video_popup",
					"description" => esc_html__( "If selected, a video popup will be appear on click.", "engic-extension" ),
					"value" => array(
						esc_html__( "No", "engic-extension" ) => '',
						esc_html__( "Yes", "engic-extension" ) => 'yes',
					),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Video Link", "engic-extension" ),
					"param_name" => "video_link",
					"value" => "",
					"description" => esc_html__( "Type video URL e.g Vimeo/YouTube.", "engic-extension" ),
					"dependency" => Array( 'element' => "video_popup", 'not_empty' => true ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Title", "engic-extension" ),
					"param_name" => "title",
					"value" => "",
					"description" => esc_html__( "Enter your title.", "engic-extension" ),
					"admin_label" => true,
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Heading", "engic-extension" ),
					"param_name" => "heading",
					"admin_label" => true,
					"value" => array( 'h1', 'h2', 'h3', 'h4' , 'h5', 'h6' ),
					"description" => esc_html__( "Heading size", "engic-extension" ),
					"std" => 'h3',
				),
				array(
					"type" => "textarea",
					"heading" => esc_html__( "Text", "engic-extension" ),
					"param_name" => "content",
					"value" => "",
					"description" => esc_html__( "Enter your text.", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Read More Title", "engic-extension" ),
					"param_name" => "read_more_title",
					"value" => "",
					"description" => esc_html__( "Enter your title for your link.", "engic-extension" ),
					"admin_label" => true,
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Read More Link Class", "engic-extension" ),
					"param_name" => "read_more_class",
					"value" => "",
					"description" => esc_html__( "Enter extra class name for your link.", "engic-extension" ),
				),
				array(
					"type" => "vc_link",
					"heading" => esc_html__( "Read More Link", "engic-extension" ),
					"param_name" => "read_more_link",
					"value" => "",
					"description" => esc_html__( "Enter read more link.", "engic-extension" ),
				),
				engic_ext_vce_add_animation(),
				engic_ext_vce_add_animation_delay(),
				engic_ext_vce_add_margin_bottom(),
				engic_ext_vce_add_el_class(),
			),
		);
	}
}

if( function_exists( 'vc_lean_map' ) ) {
	vc_lean_map( 'engic_image_text', 'engic_ext_image_text_shortcode_params' );
} else if( function_exists( 'vc_map' ) ) {
	$attributes = engic_ext_image_text_shortcode_params( 'engic_image_text' );
	vc_map( $attributes );
}

//Omit closing PHP tag to avoid accidental whitespace output errors.