<?php
/**
 * Portfolio Shortcode
 */

if( !function_exists( 'engic_ext_portfolio_shortcode' ) ) {

	function engic_ext_portfolio_shortcode( $attr, $content ) {

		$portfolio_row_start = $allow_filter = $class_fullwidth = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'categories' => '',
					'exclude_posts' => '',
					'include_posts' => '',
					'portfolio_style' => 'grid',
					'columns' => '3',
					'columns_tablet_landscape' => '2',
					'columns_tablet_portrait' => '2',
					'columns_mobile' => '1',
					'grid_image_mode' => 'landscape',
					'masonry_image_mode' => '',
					'carousel_image_mode' => 'landscape',
					'portfolio_image_mode' => '',
					'portfolio_link_type' => 'item',
					'portfolio_link_type_title' => 'More Details',
					'portfolio_filter' => '',
					'portfolio_filter_align' => 'left',
					'filter_order_by' => '',
					'filter_order' => 'ASC',
					'item_gutter' => 'yes',
					'gutter_size' => '40',
					'item_spinner' => 'no',
					'items_per_page' => '4',
					'items_to_show' => '12',
					'hide_portfolio_title' => '',
					'hide_portfolio_caption' => '',
					'hide_portfolio_like' => '',
					'portfolio_hover_style' => 'hover-style-1',
					'zoom_effect' => 'none',
					'overlay_color' => 'light',
					'overlay_opacity' => '90',
					'order_by' => 'date',
					'order' => 'DESC',
					'disable_pagination' => '',
					'slideshow_speed' => '3000',
					'auto_play' => 'yes',
					'navigation_type' => '1',
					'navigation_color' => 'dark',
					'pause_hover' => 'no',
					'animation' => 'fadeInUp',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$attr
			)
		);

		if ( !empty( $animation ) ) {
			$animation = 'eut-' . $animation;
		}

		$portfolio_classes = array( 'eut-element' );
		$data_string = '';

		switch( $portfolio_style ) {
			case 'carousel':
				$data_string = ' data-items="' . esc_attr( $items_per_page ) . '" data-slider-autoplay="' . esc_attr( $auto_play ) . '" data-slider-speed="' . esc_attr( $slideshow_speed ) . '" data-slider-pause="' . esc_attr( $pause_hover ) . '"';
				array_push( $portfolio_classes, 'eut-carousel-wrapper' );
				if ( 'popup' == $portfolio_link_type ) {
					array_push( $portfolio_classes, 'eut-gallery-popup' );
				}
				if ( 'yes' == $item_gutter ) {
					array_push( $portfolio_classes, 'eut-with-gap' );
				}
				$disable_pagination = 'yes';
				break;
			case 'masonry':
				$portfolio_row_start = '<div class="eut-isotope-container">';
				if ( 'popup' == $portfolio_link_type ) {
					$portfolio_row_start = '<div class="eut-isotope-container eut-gallery-popup">';
				}
				$data_string = ' data-spinner="' . esc_attr( $item_spinner ) . '" data-columns="' . esc_attr( $columns ) . '" data-columns-tablet-landscape="' . esc_attr( $columns_tablet_landscape ) . '" data-columns-tablet-portrait="' . esc_attr( $columns_tablet_portrait ) . '" data-columns-mobile="' . esc_attr( $columns_mobile ) . '" data-layout="masonry"';
				if ( 'yes' == $item_gutter ) {
					array_push( $portfolio_classes, 'eut-with-gap' );
					$data_string .= ' data-gutter-size="' . esc_attr( $gutter_size ) . '"';
				}
				array_push( $portfolio_classes, 'eut-portfolio' );
				array_push( $portfolio_classes, 'eut-isotope' );
				$allow_filter = 'yes';
				break;
			case 'small-media':
				$portfolio_row_start = '<div class="eut-standard-container">';
				array_push( $portfolio_classes, 'eut-portfolio' );
				array_push( $portfolio_classes, 'eut-blog' );
				array_push( $portfolio_classes, 'eut-small-media' );
				array_push( $portfolio_classes, 'eut-non-isotope' );
				$allow_filter = 'yes';
				$portfolio_link_type = 'item';
				break;
			case 'grid':
			default:
				$portfolio_row_start = '<div class="eut-isotope-container">';
				if ( 'popup' == $portfolio_link_type ) {
					$portfolio_row_start = '<div class="eut-isotope-container eut-gallery-popup">';
				}
				$data_string = ' data-gutter="' . esc_attr( $item_gutter ) . '" data-spinner="' . esc_attr( $item_spinner ) . '" data-columns="' . esc_attr( $columns ) . '" data-columns-tablet-landscape="' . esc_attr( $columns_tablet_landscape ) . '" data-columns-tablet-portrait="' . esc_attr( $columns_tablet_portrait ) . '" data-columns-mobile="' . esc_attr( $columns_mobile ) . '" data-layout="fitRows"';
				if ( 'yes' == $item_gutter ) {
					array_push( $portfolio_classes, 'eut-with-gap' );
					$data_string .= ' data-gutter-size="' . esc_attr( $gutter_size ) . '"';
				}
				array_push( $portfolio_classes, 'eut-portfolio' );
				array_push( $portfolio_classes, 'eut-isotope' );
				$allow_filter = 'yes';
				break;
		}


		if ( !empty ( $el_class ) ) {
			array_push( $portfolio_classes, $el_class);
		}
		$portfolio_class_string = implode( ' ', $portfolio_classes );

		$style = engic_ext_vce_build_margin_bottom_style( $margin_bottom );

		$portfolio_cat = "";
		$portfolio_category_ids = array();

		if( ! empty( $categories ) ) {
			$portfolio_category_ids = explode( ",", $categories );
			foreach ( $portfolio_category_ids as $category_id ) {
				$category_term = get_term( $category_id, 'portfolio_category' );
				if ( isset( $category_term) ) {
					$portfolio_cat = $portfolio_cat.$category_term->slug . ', ';
				}
			}
		}

		$paged = 1;

		if ( 'yes' != $disable_pagination ) {
			if ( get_query_var( 'paged' ) ) {
				$paged = get_query_var( 'paged' );
			} elseif ( get_query_var( 'page' ) ) {
				$paged = get_query_var( 'page' );
			}
		}

		$exclude_ids = array();
		if( !empty( $exclude_posts ) ){
			$exclude_ids = explode( ',', $exclude_posts );
		}

		$include_ids = array();
		if( !empty( $include_posts ) ){
			$include_ids = explode( ',', $include_posts );
			$args = array(
				'post_type' => 'portfolio',
				'post_status'=>'publish',
				'paged' => $paged,
				'post__in' => $include_ids,
				'posts_per_page' => $items_to_show,
				'orderby' => $order_by,
				'order' => $order,
			);
			$portfolio_filter = 'no';
		} else {
			$args = array(
				'post_type' => 'portfolio',
				'post_status'=>'publish',
				'paged' => $paged,
				'portfolio_category' => $portfolio_cat,
				'post__not_in' => $exclude_ids,
				'posts_per_page' => $items_to_show,
				'orderby' => $order_by,
				'order' => $order,
			);
		}

		$query = new WP_Query( $args );
		ob_start();
		if ( $query->have_posts() ) :
		?>
			<div class="<?php echo esc_attr( $portfolio_class_string ); ?>" style="<?php echo $style; ?>"<?php echo $data_string; ?>>
		<?php

		if ( 'yes' == $portfolio_filter && 'yes' == $allow_filter ) {

			$category_prefix = '.portfolio_category-';
			$category_filter_list = array();
			$category_filter_array = array();
			$all_string =  apply_filters( 'engic_ext_vce_portfolio_string_all_categories', esc_html__( 'All', 'engic-extension' ) );
			$category_filter_string = '<li data-filter="*" class="selected"><span>' . esc_html( $all_string ) . '</span></li>';
			$category_filter_add = false;
			while ( $query->have_posts() ) : $query->the_post();

				if ( $portfolio_categories = get_the_terms( get_the_ID(), 'portfolio_category' ) ) {

					foreach($portfolio_categories as $category_term){
						$category_filter_add = false;
						if ( !in_array($category_term->term_id, $category_filter_list) ) {
							if( ! empty( $portfolio_category_ids ) ) {
								if ( in_array($category_term->term_id, $portfolio_category_ids) ) {
									$category_filter_add = true;
								}
							} else {
								$category_filter_add = true;
							}
							if ( $category_filter_add ) {
								$category_filter_list[] = $category_term->term_id;
								if ( 'title' == $filter_order_by ) {
									$category_filter_array[$category_term->name] = $category_term;
								} elseif ( 'slug' == $filter_order_by )  {
									$category_filter_array[$category_term->slug] = $category_term;
								} else {
									$category_filter_array[$category_term->term_id] = $category_term;
								}
							}
						}
					}
				}

			endwhile;


			if ( count( $category_filter_array ) > 1 ) {
				if ( '' != $filter_order_by ) {
					if ( 'ASC' == $filter_order ) {
						ksort( $category_filter_array );
					} else {
						krsort( $category_filter_array );
					}
				}
				foreach($category_filter_array as $category_filter){
					$term_class = sanitize_html_class( $category_filter->slug, $category_filter->term_id );
					if ( is_numeric( $term_class ) || ! trim( $term_class, '-' ) ) {
						$term_class = $category_filter->term_id;
					}
					$category_filter_string .= '<li data-filter="' . $category_prefix . $term_class . '"><span>' . $category_filter->name . '</span></li>';
				}
		?>
				<div class="eut-filter eut-align-<?php echo esc_attr( $portfolio_filter_align ); ?>">
					<ul>
						<?php echo $category_filter_string; ?>
					</ul>
				</div>
		<?php
			}
		}
		?>

			<?php echo $portfolio_row_start; ?>

		<?php

		if ( 'carousel' == $portfolio_style ) {
?>
			<?php if ( 0 != $navigation_type ) { ?>
			<div class="eut-carousel-navigation eut-<?php echo esc_attr( $navigation_color ); ?>" data-navigation-type="<?php echo esc_attr( $navigation_type ); ?>">
				<div class="eut-carousel-buttons">
					<div class="eut-carousel-prev eut-icon-nav-left"></div>
					<div class="eut-carousel-next eut-icon-nav-right"></div>
				</div>
			</div>
			<?php } ?>
			<div class="eut-carousel eut-carousel-element eut-portfolio"<?php echo $data_string; ?>>
<?php
		}

		$portfolio_index = 0;

		while ( $query->have_posts() ) : $query->the_post();
			$image_size = 'engic-eutf-small-rect-horizontal';
			$portfolio_index++;
			$portfolio_extra_class = '';

			$caption = get_post_meta( get_the_ID(), '_engic_eutf_description', true );
			$details = get_post_meta( get_the_ID(), '_engic_eutf_portfolio_details', true );
			$link_mode = get_post_meta( get_the_ID(), '_engic_eutf_portfolio_link_mode', true );
			$link_url = get_post_meta( get_the_ID(), '_engic_eutf_portfolio_link_url', true );
			$new_window = get_post_meta( get_the_ID(), '_engic_eutf_portfolio_link_new_window', true );
			$link_class = get_post_meta( get_the_ID(), '_engic_eutf_portfolio_link_extra_class', true );


			if ( 'carousel' != $portfolio_style ) {
				$image_size = 'engic-eutf-small-square';
				$portfolio_extra_class = 'eut-isotope-item eut-portfolio-item ';

				if ( 'masonry' == $portfolio_style ) {
					//Masonry
					if ( 'resize' == $masonry_image_mode ) {
						$portfolio_extra_class .= 'eut-masonry-image';
						$image_size = 'large';
					} elseif( 'custom' == $masonry_image_mode ) {
						$masonry_size = get_post_meta( get_the_ID(), '_engic_eutf_portfolio_media_masonry_size', true );
						$engic_ext_masonry_data = engic_ext_vce_get_custom_masonry_data( $masonry_size );
						$portfolio_extra_class .= $engic_ext_masonry_data['class'];
						$image_size = $engic_ext_masonry_data['image_size'];
					} else {
						$engic_ext_masonry_data = engic_ext_vce_get_masonry_data( $portfolio_index, $columns );
						$portfolio_extra_class .= $engic_ext_masonry_data['class'];
						$image_size = $engic_ext_masonry_data['image_size'];
					}
				} elseif ( 'small-media' == $portfolio_style ) {
					//Small Media
					$portfolio_extra_class = 'eut-non-isotope-item eut-blog-item eut-small-post';
					$image_size = 'engic-eutf-small-rect-horizontal';
					if ( 'resize' == $portfolio_image_mode ) {
						$image_size = 'large';
					}
				} else {
					//Grid - Default
					if ( 'resize' == $grid_image_mode ) {
						$image_size = 'large';
					} elseif( 'square' == $grid_image_mode ) {
						$image_size = 'engic-eutf-small-square';
					} elseif( 'portrait' == $grid_image_mode ) {
						$image_size = 'engic-eutf-small-rect-vertical';
					} else {
						$image_size = 'engic-eutf-small-rect-horizontal';
					}
				}
			} else {

				if( 'square' == $carousel_image_mode ) {
					$image_size = 'engic-eutf-small-square';
				} elseif( 'portrait' == $carousel_image_mode ) {
					$image_size = 'engic-eutf-small-rect-vertical';
				} else {
					$image_size = 'engic-eutf-small-rect-horizontal';
				}
				$portfolio_extra_class = 'eut-portfolio-item';
				echo '<div class="eut-carousel-item">';
			}

			//Portfolio Link

			$portfolio_link_exists = true;
			$engic_ext_target = '_self';
			if( !empty( $new_window ) ) {
				$engic_ext_target = '_blank';
			}

			ob_start();
			if ( 'small-media' == $portfolio_style ) {
				?>
					<a href="<?php echo esc_url( get_permalink() ); ?>">
				<?php
			} else {
				if ( 'popup' == $portfolio_link_type ) {
				?>
					<a href="<?php engic_ext_vce_print_portfolio_image( 'full', 'link' ); ?>">
				<?php
				}  else if ( 'custom-link' == $portfolio_link_type ) {
					if ( '' == $link_mode )	{
				?>
					<a href="<?php echo esc_url( get_permalink() ); ?>">
				<?php
					} else if ( 'link' == $link_mode && !empty( $link_url ) ) {
				?>
					<a class="<?php echo esc_attr( $link_class ); ?>" href="<?php echo esc_url( $link_url ); ?>" target="<?php echo esc_attr( $engic_ext_target ); ?>">
				<?php
					} else {
						$portfolio_link_exists = false;
					}
				} else {
				?>
					<a href="<?php echo esc_url( get_permalink() ); ?>">
				<?php
				}
			}

			$link_start = ob_get_clean();

			if ( $portfolio_link_exists ) {
				$link_end = '</a>';
			} else {
				$link_end = '';
			}

?>
					<article id="portfolio-<?php the_ID(); ?><?php echo uniqid('-'); ?>" <?php post_class( $portfolio_extra_class ); ?>>
						<?php
						if ( 'carousel' == $portfolio_style ) {
						?>
							<figure class="eut-hover-style-1 eut-image-hover eut-zoom-<?php echo esc_attr( $zoom_effect ); ?> eut-<?php echo esc_attr( $overlay_color ); ?>">

								<div class="eut-media eut-<?php echo esc_attr( $overlay_color ); ?>-overlay eut-opacity-<?php echo esc_attr( $overlay_opacity ); ?>">
									<?php engic_ext_vce_print_portfolio_image( $image_size ); ?>
								</div>
								<figcaption>
									<?php
										if( function_exists( 'engic_eutf_print_portfolio_like_counter' ) && 'yes' != $hide_portfolio_like ) {
											engic_eutf_print_portfolio_like_counter();
										}
									?>
									<?php if ( 'yes' != $hide_portfolio_title  ) { ?>
									<h5 class="eut-title eut-<?php echo esc_attr( $overlay_color ); ?>"><?php the_title(); ?></h5>
									<?php } ?>
									<?php if ( !empty( $caption ) && 'yes' != $hide_portfolio_caption  ) { ?>
									<span class="eut-caption eut-<?php echo esc_attr( $overlay_color ); ?>"><?php echo wp_kses_post( $caption ); ?></span>
									<?php } ?>

									<?php
										if ( 'popup' == $portfolio_link_type ) {
									?>
										<a title="<?php the_title(); ?>" class="eut-portfolio-btns" href="<?php engic_ext_vce_print_portfolio_image( 'full', 'link' ); ?>"><?php echo $portfolio_link_type_title; ?></a>
									<?php
										} elseif ( $portfolio_link_exists ) {
											if ( 'custom-link' == $portfolio_link_type && 'link' == $link_mode) {
									?>
										<a class="eut-portfolio-btns" href="<?php echo esc_url( $link_url ); ?>" target="<?php echo esc_attr( $engic_ext_target ); ?>"><?php echo esc_html( $portfolio_link_type_title ); ?></a>
									<?php
											} else {
									?>
										<a class="eut-portfolio-btns" href="<?php echo esc_url( get_permalink() ); ?>"><?php echo esc_html( $portfolio_link_type_title ); ?></a>
									<?php
											}
										}
									?>
								</figcaption>
							</figure>
						<?php

						} elseif( 'small-media' == $portfolio_style ) {
						?>
							<div class="eut-media eut-image-hover">
								<?php echo $link_start; ?><?php engic_ext_vce_print_portfolio_image( $image_size ); ?><?php echo $link_end; ?>
							</div>
							<div class="eut-post-content">
								<?php if ( 'yes' != $hide_portfolio_title  ) { ?>
								<?php echo $link_start; ?><h5 class="eut-title"><?php the_title(); ?></h5><?php echo $link_end; ?>
								<?php } ?>
								<div class="eut-subtitle eut-post-meta">
									<?php if ( !empty( $caption ) && 'yes' != $hide_portfolio_caption  ) { ?>
									<span class="eut-caption"><?php echo wp_kses_post( $caption ); ?></span>
									<?php } ?>
								</div>
								<?php if ( !empty( $details ) ) { ?>
									<p><?php echo $details; ?></p>
								<?php } ?>
									<a class="eut-read-more" href="<?php echo esc_url( get_permalink() ); ?>"><?php echo esc_html( $portfolio_link_type_title ); ?></a>
							</div>
						<?php
						} else {

							if ( 'hover-style-2' == $portfolio_hover_style ) {
						?>
							<div class="eut-isotope-item-inner <?php echo esc_attr( $animation ); ?>">
								<?php echo $link_start; ?>
								<figure class="eut-hover-style-2 eut-image-hover eut-<?php echo esc_attr( $overlay_color ); ?>">
									<div class="eut-media eut-<?php echo esc_attr( $overlay_color ); ?>-overlay eut-opacity-<?php echo esc_attr( $overlay_opacity ); ?>">
										<?php engic_ext_vce_print_portfolio_image( $image_size ); ?>
									</div>
									<?php
										if( function_exists( 'engic_eutf_print_portfolio_like_counter' ) && 'yes' != $hide_portfolio_like ) {
											engic_eutf_print_portfolio_like_counter();
										}
									?>
									<figcaption>
										<?php if ( 'yes' != $hide_portfolio_title  ) { ?>
										<h4 class="eut-title eut-light"><?php the_title(); ?></h4>
										<?php } ?>
										<?php if ( !empty( $caption ) && 'yes' != $hide_portfolio_caption  ) { ?>
										<span class="eut-caption eut-small-text eut-light"><?php echo wp_kses_post( $caption ); ?></span>
										<?php } ?>
									</figcaption>
								</figure>
								<?php echo $link_end; ?>
							</div>
						<?php
							} else {
							//Default Hover Style 1
						?>
							<div class="eut-isotope-item-inner <?php echo esc_attr( $animation ); ?>">
								<?php echo $link_start; ?>
								<figure class="eut-hover-style-1 eut-image-hover eut-zoom-<?php echo esc_attr( $zoom_effect ); ?> eut-<?php echo esc_attr( $overlay_color ); ?>">

									<div class="eut-media eut-<?php echo esc_attr( $overlay_color ); ?>-overlay eut-opacity-<?php echo esc_attr( $overlay_opacity ); ?>">
										<?php engic_ext_vce_print_portfolio_image( $image_size ); ?>
									</div>
									<figcaption>
										<?php
											if( function_exists( 'engic_eutf_print_portfolio_like_counter' ) && 'yes' != $hide_portfolio_like ) {
												engic_eutf_print_portfolio_like_counter();
											}
										?>
										<?php if ( 'yes' != $hide_portfolio_title  ) { ?>
										<div class="eut-link-text eut-title eut-<?php echo esc_attr( $overlay_color ); ?>"><?php the_title(); ?></div>
										<?php } ?>
										<?php if ( !empty( $caption ) && 'yes' != $hide_portfolio_caption  ) { ?>
										<span class="eut-caption eut-<?php echo esc_attr( $overlay_color ); ?>"><?php echo wp_kses_post( $caption ); ?></span>
										<?php } ?>
										<?php if ( $portfolio_link_exists ) { ?>
										<span class="eut-portfolio-btns"><?php echo esc_html( $portfolio_link_type_title ); ?></span>
										<?php } ?>
									</figcaption>
								</figure>
								<?php echo $link_end; ?>
							</div>
						<?php
							}
						}
						?>

					</article>
<?php
			if ( 'carousel' == $portfolio_style ) {
				echo '</div>';
			}

		endwhile;

		?>
				</div>
<?php
			if ( 'yes' != $disable_pagination ) {
				$total = $query->max_num_pages;
				$big = 999999999; // need an unlikely integer
				if( $total > 1 )  {
					 echo '<div class="eut-pagination">';

					 if( get_option('permalink_structure') ) {
						 $format = 'page/%#%/';
					 } else {
						 $format = '&paged=%#%';
					 }
					 echo paginate_links(array(
						'base'			=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
						'format'		=> $format,
						'current'		=> max( 1, $paged ),
						'total'			=> $total,
						'mid_size'		=> 2,
						'type'			=> 'list',
						'prev_text'	=> '<i class="eut-icon-nav-left"></i>',
						'next_text'	=> '<i class="eut-icon-nav-right"></i>',
						'add_args' => false,
					 ));
					 echo '</div>';
				}
			}
?>
			</div>

		<?php

		else :
		endif;
		wp_reset_postdata();

		return ob_get_clean();

	}
	add_shortcode( 'engic_portfolio', 'engic_ext_portfolio_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

if( !function_exists( 'engic_ext_portfolio_shortcode_params' ) ) {
	function engic_ext_portfolio_shortcode_params( $tag ) {
		return array(
			"name" => esc_html__( "Portfolio", "engic-extension" ),
			"description" => esc_html__( "Display Portfolio element in multiple styles", "engic-extension" ),
			"base" => $tag,
			"class" => "",
			"icon"      => "icon-wpb-eut-portfolio",
			"category" => esc_html__( "Content", "js_composer" ),
			"params" => array(
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Style", "engic-extension" ),
					"param_name" => "portfolio_style",
					"admin_label" => true,
					'value' => array(
						esc_html__( 'Grid' , 'engic-extension' ) => 'grid',
						esc_html__( 'Masonry' , 'engic-extension' ) => 'masonry',
						esc_html__( 'Small Media' , 'engic-extension' ) => 'small-media',
						esc_html__( 'Carousel' , 'engic-extension' ) => 'carousel',
					),
					"description" => esc_html__( "Select a style for your portfolio", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Image Mode", "engic-extension" ),
					"param_name" => "portfolio_image_mode",
					'value' => array(
						esc_html__( 'Auto Crop', 'engic-extension' ) => '',
						esc_html__( 'Resize', 'engic-extension' ) => 'resize',
					),
					"description" => esc_html__( "Select your Portfolio Image Mode.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'small-media' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Grid Image Mode", "engic-extension" ),
					"param_name" => "grid_image_mode",
					'value' => array(
						esc_html__( 'Square Crop', 'engic-extension' ) => 'square',
						esc_html__( 'Landscape Crop', 'engic-extension' ) => 'landscape',
						esc_html__( 'Portrait Crop', 'engic-extension' ) => 'portrait',
						esc_html__( 'Resize ( Large )', 'engic-extension' ) => 'resize',
					),
					'std' => 'landscape',
					"description" => esc_html__( "Select your Grid Image Mode.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Masonry Image Mode", "engic-extension" ),
					"param_name" => "masonry_image_mode",
					'value' => array(
						esc_html__( 'Auto Crop', 'engic-extension' ) => '',
						esc_html__( 'Resize', 'engic-extension' ) => 'resize',
						esc_html__( 'Custom', 'engic-extension' ) => 'custom',
					),
					"description" => esc_html__( "Select your Masonry Image Mode.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Carousel Image Mode", "engic-extension" ),
					"param_name" => "carousel_image_mode",
					'value' => array(
						esc_html__( 'Square Crop', 'engic-extension' ) => 'square',
						esc_html__( 'Landscape Crop', 'engic-extension' ) => 'landscape',
						esc_html__( 'Portrait Crop', 'engic-extension' ) => 'portrait',
					),
					'std' => 'landscape',
					"description" => esc_html__( "Select your Carousel Image Mode.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'carousel' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Columns", "engic-extension" ),
					"param_name" => "columns",
					"value" => array( '2', '3', '4', '5' ),
					"std" => '3',
					"description" => esc_html__( "Select your Porfolio Columns.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Tablet Landscape Columns", "engic-extension" ),
					"param_name" => "columns_tablet_landscape",
					"value" => array( '2', '3', '4', '5' ),
					"std" => '2',
					"description" => esc_html__( "Select responsive column on tablet devices, landscape orientation.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Tablet Portrait Columns", "engic-extension" ),
					"param_name" => "columns_tablet_portrait",
					"value" => array( '2', '3', '4', '5' ),
					"std" => '2',
					"description" => esc_html__( "Select responsive column on tablet devices, portrait orientation.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Mobile Columns", "engic-extension" ),
					"param_name" => "columns_mobile",
					"value" => array( '1', '2' ),
					"std" => '1',
					"description" => esc_html__( "Select responsive column on mobile devices.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Link Type", "engic-extension" ),
					"param_name" => "portfolio_link_type",
					"admin_label" => true,
					'value' => array(
						esc_html__( 'Classic Portfolio' , 'engic-extension' ) => 'item',
						esc_html__( 'Gallery Usage' , 'engic-extension' ) => 'popup',
						esc_html__( 'Custom Link' , 'engic-extension' ) => 'custom-link',
					),
					"description" => esc_html__( "Select the link type of your portfolio items.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry', 'carousel' ) ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Link Title", "engic-extension" ),
					"param_name" => "portfolio_link_type_title",
					"value" => "More Details",
					"description" => esc_html__( "Enter your title for your link.", "engic-extension" ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Filter", "engic-extension" ),
					"param_name" => "portfolio_filter",
					"description" => esc_html__( "If selected, an isotope filter will be displayed.", "engic-extension" ),
					"value" => Array( esc_html__( "Enable Portfolio Filter ( Only for All or Multiple Categories )", "engic-extension" ) => 'yes' ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry', 'small-media' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Filter Order By", "engic-extension" ),
					"param_name" => "filter_order_by",
					"value" => array(
						esc_html__( "Default ( Unordered )", "engic-extension" ) => '',
						esc_html__( "ID", "engic-extension" ) => 'id',
						esc_html__( "Slug", "engic-extension" ) => 'slug',
						esc_html__( "Title", "engic-extension" ) => 'title',
					),
					"description" => '',
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry', 'small-media' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Filter Order", "engic-extension" ),
					"param_name" => "filter_order",
					"value" => array(
						esc_html__( "Ascending", "engic-extension" ) => 'ASC',
						esc_html__( "Descending", "engic-extension" ) => 'DESC',
					),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry', 'small-media' ) ),
					"description" => '',
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Filter Alignment", "engic-extension" ),
					"param_name" => "portfolio_filter_align",
					"value" => array(
						esc_html__( "Left", "engic-extension" ) => 'left',
						esc_html__( "Right", "engic-extension" ) => 'right',
						esc_html__( "Center", "engic-extension" ) => 'center',
					),
					"description" => '',
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry', 'small-media' ) ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Enable Loader", "engic-extension" ),
					"param_name" => "item_spinner",
					"description" => esc_html__( "If selected, this will enable a graphic spinner before load.", "engic-extension" ),
					"value" => Array( esc_html__( "Enable Loader.", "engic-extension" ) => 'yes' ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Disable Pagination", "engic-extension" ),
					"param_name" => "disable_pagination",
					"description" => esc_html__( "If selected, pagination will not be shown.", "engic-extension" ),
					"value" => Array( esc_html__( "Disable Pagination.", "engic-extension" ) => 'yes' ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry', 'small-media' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Items per page", "engic-extension" ),
					"param_name" => "items_per_page",
					"value" => array( '3', '4', '5' ),
					"description" => esc_html__( "Number of images per page", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'carousel' ) ),
					"std" => "4",
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Gutter between images", "engic-extension" ),
					"param_name" => "item_gutter",
					"value" => array(
						esc_html__( "Yes", "engic-extension" ) => 'yes',
						esc_html__( "No", "engic-extension" ) => 'no',
					),
					"description" => esc_html__( "Add gutter among images.", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Gutter Size", "engic-extension" ),
					"param_name" => "gutter_size",
					"value" => '40',
					"dependency" => array( 'element' => "item_gutter", 'value' => array( 'yes' ) ),
					"description" => esc_html__( "Note: Available only for Grid and Masonry", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Items to show", "engic-extension" ),
					"param_name" => "items_to_show",
					"value" => '12',
					"description" => esc_html__( "Maximum Portfolio Items to Show", "engic-extension" ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Hide Portfolio Title", "engic-extension" ),
					"param_name" => "hide_portfolio_title",
					"value" => Array( esc_html__( "If selected, portfolio title will be hidden", "engic-extension" ) => 'yes' ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Hide Portfolio Description", "engic-extension" ),
					"param_name" => "hide_portfolio_caption",
					"value" => Array( esc_html__( "If selected, portfolio description will be hidden", "engic-extension" ) => 'yes' ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Hide Portfolio Likes", "engic-extension" ),
					"param_name" => "hide_portfolio_like",
					"value" => Array( esc_html__( "If selected, portfolio likes will be hidden", "engic-extension" ) => 'yes' ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry', 'carousel' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Hover Style", "engic-extension" ),
					"param_name" => "portfolio_hover_style",
					'value' => array(
						esc_html__( 'Style 1' , 'engic-extension' ) => 'hover-style-1',
						esc_html__( 'Style 2' , 'engic-extension' ) => 'hover-style-2',
					),
					"description" => esc_html__( "Select hover style for portfolio items.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Image Zoom Effect", "engic-extension" ),
					"param_name" => "zoom_effect",
					"value" => array(
						esc_html__( "Zoom In", "engic-extension" ) => 'in',
						esc_html__( "Zoom Out", "engic-extension" ) => 'out',
						esc_html__( "None", "engic-extension" ) => 'none',
					),
					"description" => esc_html__( "Choose the image zoom effect.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_hover_style", 'value' => array( 'hover-style-1' ) ),
					'std' => 'none',
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Overlay Color", "engic-extension" ),
					"param_name" => "overlay_color",
					"value" => array(
						esc_html__( "Light", "engic-extension" ) => 'light',
						esc_html__( "Dark", "engic-extension" ) => 'dark',
						esc_html__( "Primary 1", "engic-extension" ) => 'primary-1',
						esc_html__( "Primary 2", "engic-extension" ) => 'primary-2',
						esc_html__( "Primary 3", "engic-extension" ) => 'primary-3',
						esc_html__( "Primary 4", "engic-extension" ) => 'primary-4',
						esc_html__( "Primary 5", "engic-extension" ) => 'primary-5',
					),
					"description" => esc_html__( "Choose the image color overlay.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry', 'carousel' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Overlay Opacity", "engic-extension" ),
					"param_name" => "overlay_opacity",
					"value" => array( '0', '10', '20', '30', '40', '50', '60', '70', '80', '90', '100' ),
					"std" => '90',
					"description" => esc_html__( "Choose the opacity for the overlay.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry', 'carousel' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__("CSS Animation", "engic-extension"),
					"param_name" => "animation",
					"value" => array(
						esc_html__( "No", "engic-extension" ) => '',
						esc_html__( "Fade In Up", "engic-extension" ) => "fadeInUp",
					),
					"std" => "fadeInUp",
					"description" => esc_html__("Select type of animation if you want this element to be animated when it enters into the browsers viewport. Note: Works only in modern browsers.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid', 'masonry' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Autoplay", "engic-extension" ),
					"param_name" => "auto_play",
					"value" => array(
						esc_html__( "Yes", "engic-extension" ) => 'yes',
						esc_html__( "No", "engic-extension" ) => 'no',
					),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'carousel' ) ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Slideshow Speed", "engic-extension" ),
					"param_name" => "slideshow_speed",
					"value" => '3000',
					"description" => esc_html__( "Slideshow Speed in ms.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'carousel' ) ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Pause on Hover", "engic-extension" ),
					"param_name" => "pause_hover",
					"value" => Array( esc_html__( "If selected, carousel will be paused on hover", "engic-extension" ) => 'yes' ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'carousel' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Navigation Type", "engic-extension" ),
					"param_name" => "navigation_type",
					'value' => array(
						esc_html__( 'Style 1' , 'engic-extension' ) => '1',
						esc_html__( 'Style 2' , 'engic-extension' ) => '2',
						esc_html__( 'Style 3' , 'engic-extension' ) => '3',
						esc_html__( 'Style 4' , 'engic-extension' ) => '4',
						esc_html__( 'No Navigation' , 'engic-extension' ) => '0',
					),
					"description" => esc_html__( "Select your Navigation type.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'carousel' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Navigation Color", "engic-extension" ),
					"param_name" => "navigation_color",
					'value' => array(
						esc_html__( 'Dark' , 'engic-extension' ) => 'dark',
						esc_html__( 'Light' , 'engic-extension' ) => 'light',
					),
					"description" => esc_html__( "Select the background Navigation color.", "engic-extension" ),
					"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'carousel' ) ),
				),
				engic_ext_vce_add_order_by(),
				engic_ext_vce_add_order(),
				engic_ext_vce_add_margin_bottom(),
				engic_ext_vce_add_el_class(),
				array(
					"type" => "textfield",
					"heading" => esc_html__("Exclude Posts", "engic-extension" ),
					"param_name" => "exclude_posts",
					"value" => '',
					"description" => esc_html__( "Type the post ids you want to exclude separated by comma ( , ).", "engic-extension" ),
					"group" => esc_html__( "Categories", "engic-extension" ),
				),
				array(
					"type" => "engic_ext_multi_checkbox",
					"heading" => esc_html__("Portfolio Categories", "engic-extension" ),
					"param_name" => "categories",
					"value" => engic_ext_vce_get_portfolio_categories(),
					"description" => esc_html__( "Select all or multiple categories.", "engic-extension" ),
					"admin_label" => true,
					"group" => esc_html__( "Categories", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__("Include Specific Posts", "engic-extension" ),
					"param_name" => "include_posts",
					"value" => '',
					"description" => esc_html__( "Type the specific post ids you want to include separated by comma ( , ). Note: If you define specific post ids, Exclude Posts and Categories will have no effect.", "engic-extension" ),
					"group" => esc_html__( "Categories", "engic-extension" ),
				),
			),
		);
	}
}

if( function_exists( 'vc_lean_map' ) ) {
	vc_lean_map( 'engic_portfolio', 'engic_ext_portfolio_shortcode_params' );
} else if( function_exists( 'vc_map' ) ) {
	$attributes = engic_ext_portfolio_shortcode_params( 'engic_portfolio' );
	vc_map( $attributes );
}

//Omit closing PHP tag to avoid accidental whitespace output errors.