<?php
/**
 * Pricing Table Shortcode
 */

if( !function_exists( 'engic_ext_pricing_table_shortcode' ) ) {

	function engic_ext_pricing_table_shortcode( $atts, $content ) {

		$output = $data = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'title' => '',
					'heading' => 'h3',
					'price' => '',
					'interval' => '',
					'values' => '',
					'table_color' => 'grey',
					'button_text' => '',
					'button_link' => '',
					'button_type' => 'simple',
					'button_size' => 'medium',
					'button_color' => 'primary-1',
					'button_shape' => 'square',
					'button_class' => '',
					'bg_color' => '',
					'animation' => '',
					'animation_delay' => '200',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$atts
			)
		);

		if ( !empty( $animation ) ) {
			$animation = 'eut-' . $animation;
		}

		$button = engic_ext_vce_get_button( $button_text, $button_link, $button_type, $button_size, $button_color, $button_shape, $button_class );

		//Pricing Table Classes
		$pricing_classes = array( 'eut-element', 'eut-pricing-table' );
		if ( !empty( $animation ) ) {
			array_push( $pricing_classes, 'eut-animated-item' );
			array_push( $pricing_classes, $animation);
			$data = ' data-delay="' . esc_attr( $animation_delay ) . '"';
		}

		if ( !empty ( $el_class ) ) {
			array_push( $pricing_classes, $el_class);
		}
		$pricing_class_string = implode( ' ', $pricing_classes );

		//Pricing Lines
		$pricing_lines = explode(",", $values);

		$pricing_lines_data = array();
		foreach ($pricing_lines as $line) {
			$new_line = array();
			$data_line = explode("|", $line);
			$new_line['value1'] = isset( $data_line[0] ) && !empty( $data_line[0] ) ? $data_line[0] : '';
			$new_line['value2'] = isset( $data_line[1] ) && !empty( $data_line[1] ) ? $data_line[1] : '';
			$pricing_lines_data[] = $new_line;
		}

		$style = engic_ext_vce_build_margin_bottom_style( $margin_bottom );

		$output .= '<div class="' . $pricing_class_string . '" style="' . $style . '"' . $data . '>';
		$output .= '  <div class="eut-pricing-header">';
		$output .= '    <div class="eut-subtitle eut-pricing-title eut-bg-' . $table_color . '">' . $title . '</div>';
		$output .= '    <' . $heading . ' class="eut-price eut-bg-' . $table_color . '">' . $price . ' <span>' . $interval . '</span></' . $heading . '>';
	    $output .= '  </div>';
	    $output .= '  <ul>';
		foreach($pricing_lines_data as $line) {
			$output .= '<li><strong>' .  $line['value1'] . ' </strong>' .  $line['value2'] . '</li>';
		}
		$output .= '  </ul>';
		$output .= $button;
		$output .= '</div>';

		return $output;
	}
	add_shortcode( 'engic_pricing_table', 'engic_ext_pricing_table_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

if( !function_exists( 'engic_ext_pricing_table_shortcode_params' ) ) {
	function engic_ext_pricing_table_shortcode_params( $tag ) {
		return array(
			"name" => esc_html__( "Pricing Table", "engic-extension" ),
			"description" => esc_html__( "Stylish pricing tables", "engic-extension" ),
			"base" => $tag,
			"class" => "",
			"icon"      => "icon-wpb-eut-pricing-table",
			"category" => esc_html__( "Content", "js_composer" ),
			"params" => array(
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Title", "engic-extension" ),
					"param_name" => "title",
					"value" => "Title",
					"save_always" => true,
					"description" => esc_html__( "Enter your title here.", "engic-extension" ),
					"admin_label" => true,
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Heading", "engic-extension" ),
					"param_name" => "heading",
					"admin_label" => true,
					"value" => array( 'h1', 'h2', 'h3', 'h4' , 'h5', 'h6' ),
					"description" => esc_html__( "Heading size", "engic-extension" ),
					"std" => "h3",
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Price", "engic-extension" ),
					"param_name" => "price",
					"value" => "$0",
					"save_always" => true,
					"description" => esc_html__( "Enter your price here. eg $80.", "engic-extension" ),
					"admin_label" => true,
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Interval", "engic-extension" ),
					"param_name" => "interval",
					"value" => "/month",
					"save_always" => true,
					"description" => esc_html__( "Enter interval period here. e.g: /month, per month, per year.", "engic-extension" ),
				),
				array(
					"type" => "exploded_textarea",
					"heading" => esc_html__("Attributes", "engic-extension"),
					"param_name" => "values",
					"description" => esc_html__( "Input attribute values. Divide values with linebreaks (Enter). Example: 100|Users.", "engic-extension" ),
					"value" => "100|Users,8 Gig|Disc Space,Unlimited|Data Transfer",
					"save_always" => true,
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Pricing Table Color", "engic-extension" ),
					"param_name" => "table_color",
					"value" => array(
						esc_html__( "Primary 1", "engic-extension" ) => 'primary-1',
						esc_html__( "Primary 2", "engic-extension" ) => 'primary-2',
						esc_html__( "Primary 3", "engic-extension" ) => 'primary-3',
						esc_html__( "Primary 4", "engic-extension" ) => 'primary-4',
						esc_html__( "Primary 5", "engic-extension" ) => 'primary-5',
						esc_html__( "Green", "engic-extension" ) => 'green',
						esc_html__( "Orange", "engic-extension" ) => 'orange',
						esc_html__( "Red", "engic-extension" ) => 'red',
						esc_html__( "Blue", "engic-extension" ) => 'blue',
						esc_html__( "Aqua", "engic-extension" ) => 'aqua',
						esc_html__( "Purple", "engic-extension" ) => 'purple',
						esc_html__( "Black", "engic-extension" ) => 'black',
						esc_html__( "Grey", "engic-extension" ) => 'grey',
					),
					'std' => 'grey',
				),
				engic_ext_vce_add_button_text(),
				engic_ext_vce_add_button_link(),
				engic_ext_vce_add_button_type(),
				engic_ext_vce_add_button_color(),
				engic_ext_vce_add_button_size(),
				engic_ext_vce_add_button_shape(),
				engic_ext_vce_add_button_class(),
				engic_ext_vce_add_animation(),
				engic_ext_vce_add_animation_delay(),
				engic_ext_vce_add_margin_bottom(),
				engic_ext_vce_add_el_class(),
			),
		);
	}
}

if( function_exists( 'vc_lean_map' ) ) {
	vc_lean_map( 'engic_pricing_table', 'engic_ext_pricing_table_shortcode_params' );
} else if( function_exists( 'vc_map' ) ) {
	$attributes = engic_ext_pricing_table_shortcode_params( 'engic_pricing_table' );
	vc_map( $attributes );
}

//Omit closing PHP tag to avoid accidental whitespace output errors.