<?php
/**
* Single Image Shortcode
*/

if( !function_exists( 'engic_ext_single_image_shortcode' ) ) {

	function engic_ext_single_image_shortcode( $attr, $content ) {

		$output = $data = $retina_data = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'image_mode' => '',
					'image' => '',
					'retina_image' => '',
					'image_type' => 'image',
					'image_hover_style' => 'hover-style-1',
					'custom_title' => '',
					'custom_caption' => '',
					'zoom_effect' => 'in',
					'overlay_color' => 'dark',
					'overlay_opacity' => '80',
					'align' => 'center',
					'link' => '',
					'video_link' => '',
					'animation' => '',
					'animation_delay' => '200',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$attr
			)
		);

		if ( !empty( $animation ) ) {
			$animation = 'eut-' . $animation;
		}

		if ( !empty( $link ) ){
			$href = vc_build_link( $link );
			$url = $href['url'];
			if ( !empty( $href['target'] ) ){
				$target = $href['target'];
			} else {
				$target = "_self";
			}
		} else {
			$url = "#";
			$target = "_self";
		}
		$target = trim( $target );

		$single_image_classes = array( 'eut-element', 'eut-image' );

		if ( !empty( $animation ) ) {
			array_push( $single_image_classes, 'eut-animated-item' );
			array_push( $single_image_classes, $animation);
			$data = ' data-delay="' . esc_attr( $animation_delay ) . '"';
		}
		if ( !empty( $el_class ) ) {
			array_push( $single_image_classes, $el_class);
		}
		if ( 'image-caption' != $image_type ) {
			array_push( $single_image_classes, 'eut-align-' . $align );
		}
		$single_image_classe_string = implode( ' ', $single_image_classes );

		$image_mode_size = engic_ext_vce_get_image_size( $image_mode );


		$style = engic_ext_vce_build_margin_bottom_style( $margin_bottom );

		$output .= '<div class="' . esc_attr( $single_image_classe_string ) . '" style="' . $style . '"' . $data . '>';

		if ( !empty( $image ) ) {
			$image_html = '';
			$id = preg_replace('/[^\d]/', '', $image);
			$image_link_href =  wp_get_attachment_url( $id );
			$img_src = wp_get_attachment_image_src( $id, $image_mode_size );
			if ( $img_src ) {
				$img_url = $img_src[0];
				$image_srcset = '';

				$full_src = wp_get_attachment_image_src( $id, 'engic-eutf-fullscreen' );
				if ( !empty( $retina_image ) && empty( $image_mode ) ) {
					$img_retina_id = preg_replace('/[^\d]/', '', $retina_image);
					$img_retina_src = wp_get_attachment_image_src( $img_retina_id, 'full' );
					if ( $img_retina_src ) {
						$retina_url = $img_retina_src[0];
						$image_srcset = esc_url( $img_url ) . ' 1x,' . esc_url( $retina_url ) . ' 2x';
						$image_html = wp_get_attachment_image( $id, 'full' , "", array( 'srcset'=> $image_srcset ) );
					} else {
						$image_html = wp_get_attachment_image( $id, $image_mode_size );
					}
				} else {
					$image_html = wp_get_attachment_image( $id, $image_mode_size );
				}
			}

			if ( 'image-popup' == $image_type ) {
				if ( $img_src ) {
					$output .= '<a class="eut-image-popup" href="' . esc_url( $full_src[0] ) . '">';
					$output .= $image_html;
					$output .= '</a>';
				}
			} else if ( 'image-link' == $image_type ) {
				$output .= '<a href="' . esc_url( $url ) . '" target="' . esc_attr( $target ) . '">';
				$output .= $image_html;
				$output .= '</a>';
			} else if ( 'image-video-popup' == $image_type ) {
				if ( !empty( $video_link ) ) {
					$output .= '<div class="eut-media">';
					$output .= '<a class="eut-vimeo-popup eut-icon-video" href="' . esc_url( $video_link ) . '">';
					$output .= $image_html;
					$output .= '</a>';
					$output .= '</div>';
				} else {
					$output .= '<div class="eut-media">';
					$output .= $image_html;
					$output .= '</div>';
				}
			} else if ( 'image-caption' == $image_type ) {
				if ( !empty( $url ) && '#' != $url ) {
				$output .= '<a href="' . esc_url( $url ) . '" target="' . esc_attr( $target ) . '">';
				}
				$output .= '  <figure class="eut-' . esc_attr( $image_hover_style ) . ' eut-image-hover eut-zoom-' . esc_attr( $zoom_effect ) . '">';
				$output .= '    <div class="eut-media eut-' . esc_attr( $overlay_color ) . '-overlay eut-opacity-' . esc_attr( $overlay_opacity ) . '">';
				$output .= $image_html;
				$output .= '    </div>';
				$output .= '      <figcaption>';
					if ( !empty( $custom_title ) ) {
						$output .= '<h6 class="eut-title eut-' . esc_attr( $overlay_color ) . '">' . $custom_title . '</h6>';
					}
					if ( !empty( $custom_caption ) ) {
						$output .= '<span class="eut-caption eut-' . esc_attr( $overlay_color ) . '">' . $custom_caption . '</span>';
					}

				$output .= '      </figcaption>';
				$output .= '  </figure>';
				if ( !empty( $url ) && '#' != $url ) {
				$output .= '</a>';
				}
			} else {
				$output .= $image_html;
			}
		}

		$output .= '</div>';

		return $output;

	}
	add_shortcode( 'engic_single_image', 'engic_ext_single_image_shortcode' );

}

/**
* Add shortcode to Visual Composer
*/

if( !function_exists( 'engic_ext_single_image_shortcode_params' ) ) {
	function engic_ext_single_image_shortcode_params( $tag ) {
		return array(
			"name" => esc_html__( "Single Image", "engic-extension" ),
			"description" => esc_html__( "Image or Video popup in various uses", "engic-extension" ),
			"base" => $tag,
			"class" => "",
			"icon"      => "icon-wpb-eut-single-image",
			"category" => esc_html__( "Content", "js_composer" ),
			"params" => array(
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Type", "engic-extension" ),
					"param_name" => "image_type",
					"value" => array(
						esc_html__( "Image", "engic-extension" ) => 'image',
						esc_html__( "Image Link", "engic-extension" ) => 'image-link',
						esc_html__( "Image Popup", "engic-extension" ) => 'image-popup',
						esc_html__( "Image Video Popup", "engic-extension" ) => 'image-video-popup',
						esc_html__( "Image With Caption", "engic-extension" ) => 'image-caption',
					),
					"description" => esc_html__( "Select your image type.", "engic-extension" ),
					"admin_label" => true,
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Image Mode", "engic-extension" ),
					"param_name" => "image_mode",
					'value' => array(
						esc_html__( 'Full ( Custom )', 'engic-extension' ) => '',
						esc_html__( 'Thumbnail', 'engic-extension' ) => 'thumbnail',
						esc_html__( 'Medium ( Resize )', 'engic-extension' ) => 'medium',
						esc_html__( 'Large ( Resize )', 'engic-extension' ) => 'large',
						esc_html__( 'Square ( Crop )', 'engic-extension' ) => 'square',
						esc_html__( 'Landscape ( Crop )', 'engic-extension' ) => 'landscape',
						esc_html__( 'Landscape Wide ( Crop )', 'engic-extension' ) => 'landscape-wide',
						esc_html__( 'Portrait ( Crop )', 'engic-extension' ) => 'portrait',
					),
					'std' => '',
					"description" => esc_html__( "Select your Image Mode.", "engic-extension" ),
				),
				array(
					"type" => "attach_image",
					"heading" => esc_html__( "Image", "engic-extension" ),
					"param_name" => "image",
					"value" => '',
					"description" => esc_html__( "Select an image.", "engic-extension" ),
				),
				array(
					"type" => "attach_image",
					"heading" => esc_html__( "Retina Image", "engic-extension" ),
					"param_name" => "retina_image",
					"value" => '',
					"description" => esc_html__( "Select a 2x image.", "engic-extension" ),
					"dependency" => array( 'element' => "image_mode", 'value' => array( '' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => __( "Alignment", "engic-extension" ),
					"param_name" => "align",
					"value" => array(
						__( "Left", "engic-extension" ) => 'left',
						__( "Right", "engic-extension" ) => 'right',
						__( "Center", "engic-extension" ) => 'center',
					),
					"dependency" => Array( 'element' => "image_type", 'value' => array( 'image', 'image-link', 'image-popup', 'image-video-popup') ),
					"std" => 'center',
				),
				array(
					"type" => "dropdown",
					"heading" => __( "Hover Style", "engic-extension" ),
					"param_name" => "image_hover_style",
					'value' => array(
						__( 'Style 1' , 'engic-extension' ) => 'hover-style-1',
						__( 'Style 2' , 'engic-extension' ) => 'hover-style-2',
					),
					"description" => __( "Select hover style for image items.", "engic-extension" ),
					"dependency" => Array( 'element' => "image_type", 'value' => array( 'image-caption' ) ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Title", "engic-extension" ),
					"param_name" => "custom_title",
					"value" => "",
					"description" => esc_html__( "Enter your title.", "engic-extension" ),
					"admin_label" => true,
					"dependency" => Array( 'element' => "image_type", 'value' => array( 'image-caption' ) ),
				),
				array(
					"type" => "textarea",
					"heading" => esc_html__( "Caption", "engic-extension" ),
					"param_name" => "custom_caption",
					"value" => "",
					"description" => esc_html__( "Enter your caption.", "engic-extension" ),
					"dependency" => Array( 'element' => "image_type", 'value' => array( 'image-caption' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Image Zoom Effect", "engic-extension" ),
					"param_name" => "zoom_effect",
					"value" => array(
						esc_html__( "Zoom In", "engic-extension" ) => 'in',
						esc_html__( "Zoom Out", "engic-extension" ) => 'out',
						esc_html__( "None", "engic-extension" ) => 'none',
					),
					"description" => esc_html__( "Choose the image zoom effect.", "engic-extension" ),
					"dependency" => Array( 'element' => "image_type", 'value' => array( 'image-caption' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Overlay Color", "engic-extension" ),
					"param_name" => "overlay_color",
					"value" => array(
						esc_html__( "Dark", "engic-extension" ) => 'dark',
						esc_html__( "Light", "engic-extension" ) => 'light',
						esc_html__( "Primary 1", "engic-extension" ) => 'primary-1',
						esc_html__( "Primary 2", "engic-extension" ) => 'primary-2',
						esc_html__( "Primary 3", "engic-extension" ) => 'primary-3',
						esc_html__( "Primary 4", "engic-extension" ) => 'primary-4',
						esc_html__( "Primary 5", "engic-extension" ) => 'primary-5',
					),
					"description" => esc_html__( "Choose the image color overlay.", "engic-extension" ),
					"dependency" => Array( 'element' => "image_type", 'value' => array( 'image-caption' ) ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Overlay Opacity", "engic-extension" ),
					"param_name" => "overlay_opacity",
					"value" => array( '0', '10', '20', '30', '40', '50', '60', '70', '80', '90', '100' ),
					"std" => '80',
					"description" => esc_html__( "Choose the opacity for the overlay.", "engic-extension" ),
					"dependency" => Array( 'element' => "image_type", 'value' => array( 'image-caption' ) ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Video Link", "engic-extension" ),
					"param_name" => "video_link",
					"value" => "",
					"description" => esc_html__( "Type video URL e.g Vimeo/YouTube.", "engic-extension" ),
					"dependency" => Array( 'element' => "image_type", 'value' => array( 'image-video-popup') ),
				),
				array(
					"type" => "vc_link",
					"heading" => esc_html__( "Link", "engic-extension" ),
					"param_name" => "link",
					"value" => "",
					"description" => esc_html__( "Enter link.", "engic-extension" ),
					"dependency" => Array( 'element' => "image_type", 'value' => array( 'image-link', 'image-caption' ) ),
				),
				engic_ext_vce_add_animation(),
				engic_ext_vce_add_animation_delay(),
				engic_ext_vce_add_margin_bottom(),
				engic_ext_vce_add_el_class(),
			),
		);
	}
}

if( function_exists( 'vc_lean_map' ) ) {
	vc_lean_map( 'engic_single_image', 'engic_ext_single_image_shortcode_params' );
} else if( function_exists( 'vc_map' ) ) {
	$attributes = engic_ext_single_image_shortcode_params( 'engic_single_image' );
	vc_map( $attributes );
}

//Omit closing PHP tag to avoid accidental whitespace output errors.