<?php
/**
 * Slider Shortcode
 */

if( !function_exists( 'engic_ext_slider_shortcode' ) ) {

	function engic_ext_slider_shortcode( $attr, $content ) {

		$output = $class_fullwidth = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'ids' => '',
					'image_mode' => 'resize',
					'slideshow_speed' => '3500',
					'navigation_type' => '1',
					'navigation_color' => 'dark',
					'pause_hover' => 'no',
					'auto_play' => 'yes',
					'auto_height' => 'no',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$attr
			)
		);

		$attachments = explode( ",", $ids );

		if ( empty( $attachments ) ) {
			return '';
		}

		$image_size = 'large';
		if ( 'autocrop' == $image_mode ) {
			$image_size = 'engic-eutf-large-rect-horizontal';
		}

		$style = engic_ext_vce_build_margin_bottom_style( $margin_bottom );

		$slider_data = '';
		$slider_data .= ' data-slider-speed="' . esc_attr( $slideshow_speed ) . '"';
		$slider_data .= ' data-slider-pause="' . esc_attr( $pause_hover ) . '"';
		$slider_data .= ' data-navigation-type="' . esc_attr( $navigation_type ) . '"';
		$slider_data .= ' data-slider-autoplay="' . esc_attr( $auto_play ) . '"';
		$slider_data .= ' data-slider-autoheight="' . esc_attr( $auto_height ) . '"';

		$output .= '<div class="eut-element eut-carousel-wrapper"  style="' . $style . ' ">';

		if ( 0 != $navigation_type ) {
			$output .= '<div class="eut-carousel-navigation eut-' . esc_attr( $navigation_color ) . '" data-navigation-type="' . esc_attr( $navigation_type ) . '">';
			$output .= '	<div class="eut-carousel-buttons">';
			$output .= '		<div class="eut-carousel-prev eut-icon-nav-left"></div>';
			$output .= '		<div class="eut-carousel-next eut-icon-nav-right"></div>';
			$output .= '	</div>';
			$output .= '</div>';
		}

		$output .= '<div class="eut-slider eut-carousel-element ' . esc_attr( $el_class ) . '"' . $slider_data . '>';

		foreach ( $attachments as $id ) {
			$image_link_href =  wp_get_attachment_url( $id );

			$output .= '<div class="eut-slider-item">';
			$output .= '<figure>';
			$output .= '<div class="eut-media">';
			$output .= wp_get_attachment_image( $id, $image_size );
			$output .= '</div>';
			$output .= '</figure>';
			$output .= '</div>';

		}
		$output .= '	</div>';
		$output .= '</div>';

		return $output;

	}
	add_shortcode( 'engic_slider', 'engic_ext_slider_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

if( !function_exists( 'engic_ext_slider_shortcode_params' ) ) {
	function engic_ext_slider_shortcode_params( $tag ) {
		return array(
			"name" => esc_html__( "Slider", "engic-extension" ),
			"description" => esc_html__( "Create a simple slider", "engic-extension" ),
			"base" => $tag,
			"class" => "",
			"icon"      => "icon-wpb-eut-slider",
			"category" => esc_html__( "Content", "js_composer" ),
			"params" => array(
				array(
					"type"			=> "attach_images",
					"admin_label"	=> true,
					"class"			=> "",
					"heading"		=> esc_html__( "Attach Images", "engic-extension" ),
					"param_name"	=> "ids",
					"value" => '',
					"description"	=> esc_html__( "Select your slider images.", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Image Mode", "engic-extension" ),
					"param_name" => "image_mode",
					'value' => array(
						esc_html__( 'Resize', 'engic-extension' ) => 'resize',
						esc_html__( 'Auto Crop', 'engic-extension' ) => 'autocrop',
					),
					"description" => esc_html__( "Select your slider image mode.", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Autoplay", "engic-extension" ),
					"param_name" => "auto_play",
					"value" => array(
						esc_html__( "Yes", "engic-extension" ) => 'yes',
						esc_html__( "No", "engic-extension" ) => 'no',
					),
				),
				engic_ext_vce_add_slideshow_speed(),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Pause on Hover", "engic-extension" ),
					"param_name" => "pause_hover",
					"value" => Array( esc_html__( "If selected, slider will be paused on hover", "engic-extension" ) => 'yes' ),
				),
				engic_ext_vce_add_auto_height(),
				engic_ext_vce_add_navigation_type(),
				engic_ext_vce_add_navigation_color(),
				engic_ext_vce_add_margin_bottom(),
				engic_ext_vce_add_el_class(),
			),
		);
	}
}

if( function_exists( 'vc_lean_map' ) ) {
	vc_lean_map( 'engic_slider', 'engic_ext_slider_shortcode_params' );
} else if( function_exists( 'vc_map' ) ) {
	$attributes = engic_ext_slider_shortcode_params( 'engic_slider' );
	vc_map( $attributes );
}

//Omit closing PHP tag to avoid accidental whitespace output errors.