<?php
/**
 * Slogan Shortcode
 */

if( !function_exists( 'engic_ext_slogan_shortcode' ) ) {

	function engic_ext_slogan_shortcode( $atts, $content ) {

		$output = $data = $el_class = $text_style_class = '';

		extract(
			shortcode_atts(
				array(
					'title' => '',
					'heading' => 'h1',
					'line_type' => 'no-line',
					'subtitle' => '',
					'button_text' => '',
					'button_link' => '',
					'button_type' => 'simple',
					'button_size' => 'medium',
					'button_color' => 'primary-1',
					'button_shape' => 'square',
					'button_class' => '',
					'button2_text' => '',
					'button2_link' => '',
					'button2_type' => 'simple',
					'button2_size' => 'medium',
					'button2_color' => 'primary-1',
					'button2_shape' => 'square',
					'button2_class' => '',
					'text_style' => 'none',
					'align' => 'left',
					'animation' => '',
					'animation_delay' => '200',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$atts
			)
		);

		if ( !empty( $animation ) ) {
			$animation = 'eut-' . $animation;
		}

		//Title
		if ( !empty( $title ) ) {
			//Title Classes
			$title_classes = array( 'eut-slogan-title' );

			array_push( $title_classes, 'eut-align-' . $align );
			array_push( $title_classes, 'eut-title-' . $line_type );

			$title_class_string = implode( ' ', $title_classes );
		}

		//Slogan
		$slogan_classes = array( 'eut-element', 'eut-slogan', 'eut-align-' . $align );

		if ( !empty( $animation ) ) {
			array_push( $slogan_classes, 'eut-animated-item' );
			array_push( $slogan_classes, $animation);
			$data = ' data-delay="' . esc_attr( $animation_delay ) . '"';
		}
		if ( !empty( $el_class ) ) {
			array_push( $slogan_classes, $el_class);
		}
		$slogan_class_string = implode( ' ', $slogan_classes );

		// Paragraph
		if ( 'none' != $text_style ) {
			$text_style_class = 'eut-' .$text_style;
		}

		//First Button
		$button1 = engic_ext_vce_get_button( $button_text, $button_link, $button_type, $button_size, $button_color, $button_shape, $button_class );
		//Second Button
		$button2 = engic_ext_vce_get_button( $button2_text, $button2_link, $button2_type, $button2_size, $button2_color, $button2_shape, $button2_class );

		$style = engic_ext_vce_build_margin_bottom_style( $margin_bottom );

		$output .= '<div class="' . esc_attr( $slogan_class_string ) . '" style="' . $style. '"' . $data . '>';
		if ( !empty( $subtitle ) ) {
			$output .= '<div class="eut-subtitle">' . $subtitle . '</div>';
		}
		if ( !empty( $title ) ) {
			$output .= '<' . $heading . ' class="' . esc_attr( $title_class_string ) . '"><span>' . $title . '</span></' . $heading . '>';
		}
		if ( !empty( $content ) ) {
			$output .= '  <p class="' . esc_attr( $text_style_class ) . '">' . $content . '</p>';
		}

		if ( !empty( $button1 ) || !empty( $button2 ) ) {
			$output .= '<div class="eut-btn-wrapper">';
			$output .= $button1;
			$output .= $button2;
			$output .= '</div>';
		}
		$output .= '</div>';

		return $output;
	}
	add_shortcode( 'engic_slogan', 'engic_ext_slogan_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

if( !function_exists( 'engic_ext_slogan_shortcode_params' ) ) {
	function engic_ext_slogan_shortcode_params( $tag ) {
		return array(
			"name" => esc_html__( "Slogan", "engic-extension" ),
			"description" => esc_html__( "Create easily appealing slogans", "engic-extension" ),
			"base" => $tag,
			"class" => "",
			"icon"      => "icon-wpb-eut-slogan",
			"category" => esc_html__( "Content", "js_composer" ),
			"params" => array(
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Title", "engic-extension" ),
					"param_name" => "title",
					"value" => "Sample Title",
					"description" => esc_html__( "Enter your title here.", "engic-extension" ),
					"save_always" => true,
					"admin_label" => true,
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Heading", "engic-extension" ),
					"param_name" => "heading",
					"admin_label" => true,
					"value" => array( 'h1', 'h2', 'h3', 'h4' , 'h5', 'h6' ),
					"description" => esc_html__( "Heading size of the title", "engic-extension" ),
					"std" => 'h1',
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Line type", "engic-extension" ),
					"param_name" => "line_type",
					"value" => array(
						esc_html__( "None", "engic-extension" ) => 'no-line',
						esc_html__( "Simple", "engic-extension" ) => 'line',
						esc_html__( "Double", "engic-extension" ) => 'double-line',
						esc_html__( "Double Bottom", "engic-extension" ) => 'double-bottom-line',
					),
					"description" => esc_html__( "Line Type of the title.", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Sub-Title", "engic-extension" ),
					"param_name" => "subtitle",
					"value" => "",
					"description" => esc_html__( "Enter your sub-title here.", "engic-extension" ),
					"admin_label" => true,
				),
				array(
					"type" => "textarea",
					"heading" => esc_html__( "Text", "engic-extension" ),
					"param_name" => "content",
					"value" => "",
					"description" => esc_html__( "Type your text.", "engic-extension" ),
					"admin_label" => true,
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Text Style", "engic-extension" ),
					"param_name" => "text_style",
					"value" => array(
						esc_html__( "None", "engic-extension" ) => '',
						esc_html__( "Leader", "engic-extension" ) => 'leader-text',
						esc_html__( "Subtitle", "engic-extension" ) => 'subtitle',
					),
					"description" => 'Select your text style',
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "First Button type", "engic-extension" ),
					"param_name" => "button_type",
					"value" => array(
						esc_html__( "Simple", "engic-extension" ) => 'simple',
						esc_html__( "Outline", "engic-extension" ) => 'outline',
					),
					"description" => esc_html__( "Select button type.", "engic-extension" ),
					"group" => esc_html__( "First Button", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "First Button Color", "engic-extension" ),
					"param_name" => "button_color",
					"value" => array(
						esc_html__( "Primary 1", "engic-extension" ) => 'primary-1',
						esc_html__( "Primary 2", "engic-extension" ) => 'primary-2',
						esc_html__( "Primary 3", "engic-extension" ) => 'primary-3',
						esc_html__( "Primary 4", "engic-extension" ) => 'primary-4',
						esc_html__( "Primary 5", "engic-extension" ) => 'primary-5',
						esc_html__( "Green", "engic-extension" ) => 'green',
						esc_html__( "Orange", "engic-extension" ) => 'orange',
						esc_html__( "Red", "engic-extension" ) => 'red',
						esc_html__( "Blue", "engic-extension" ) => 'blue',
						esc_html__( "Aqua", "engic-extension" ) => 'aqua',
						esc_html__( "Purple", "engic-extension" ) => 'purple',
						esc_html__( "Black", "engic-extension" ) => 'black',
						esc_html__( "Grey", "engic-extension" ) => 'grey',
						esc_html__( "White", "engic-extension" ) => 'white',
					),
					"description" => esc_html__( "Color of the button.", "engic-extension" ),
					"group" => esc_html__( "First Button", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "First Button Text", "engic-extension" ),
					"param_name" => "button_text",
					"value" => "",
					"description" => esc_html__( "Leave this field empty if you don't want to show this button.", "engic-extension" ),
					"group" => esc_html__( "First Button", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "First Button Size", "engic-extension" ),
					"param_name" => "button_size",
					"value" => array(
						esc_html__( "Extra Small", "engic-extension" ) => 'extrasmall',
						esc_html__( "Small", "engic-extension" ) => 'small',
						esc_html__( "Medium", "engic-extension" ) => 'medium',
						esc_html__( "Large", "engic-extension" ) => 'large',
						esc_html__( "Extra Large", "engic-extension" ) => 'extralarge',
					),
					"description" => '',
					"std" => 'medium',
					"admin_label" => true,
					"group" => esc_html__( "First Button", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "First Button Shape", "engic-extension" ),
					"param_name" => "button_shape",
					"value" => array(
						esc_html__( "Square", "engic-extension" ) => 'square',
						esc_html__( "Round", "engic-extension" ) => 'round',
						esc_html__( "Extra Round", "engic-extension" ) => 'extra-round',
					),
					"description" => '',
					"std" => 'square',
					"group" => esc_html__( "First Button", "engic-extension" ),
				),
				array(
					"type" => "vc_link",
					"heading" => esc_html__( "First Button Link", "engic-extension" ),
					"param_name" => "button_link",
					"value" => "",
					"description" => esc_html__( "Enter a link for your button.", "engic-extension" ),
					"group" => esc_html__( "First Button", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "First Button class name", "engic-extension" ),
					"param_name" => "button_class",
					"description" => esc_html__( "If you wish to style your button differently, then use this field to add a class name and then refer to it in your css file.", "engic-extension" ),
					"group" => esc_html__( "First Button", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Second Button type", "engic-extension" ),
					"param_name" => "button2_type",
					"value" => array(
						esc_html__( "Simple", "engic-extension" ) => 'simple',
						esc_html__( "Outline", "engic-extension" ) => 'outline',
					),
					"description" => esc_html__( "Select button type.", "engic-extension" ),
					"group" => esc_html__( "Second Button", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Second Button Color", "engic-extension" ),
					"param_name" => "button2_color",
					"value" => array(
						esc_html__( "Primary 1", "engic-extension" ) => 'primary-1',
						esc_html__( "Primary 2", "engic-extension" ) => 'primary-2',
						esc_html__( "Primary 3", "engic-extension" ) => 'primary-3',
						esc_html__( "Primary 4", "engic-extension" ) => 'primary-4',
						esc_html__( "Primary 5", "engic-extension" ) => 'primary-5',
						esc_html__( "Green", "engic-extension" ) => 'green',
						esc_html__( "Orange", "engic-extension" ) => 'orange',
						esc_html__( "Red", "engic-extension" ) => 'red',
						esc_html__( "Blue", "engic-extension" ) => 'blue',
						esc_html__( "Aqua", "engic-extension" ) => 'aqua',
						esc_html__( "Purple", "engic-extension" ) => 'purple',
						esc_html__( "Black", "engic-extension" ) => 'black',
						esc_html__( "Grey", "engic-extension" ) => 'grey',
						esc_html__( "White", "engic-extension" ) => 'white',
					),
					"description" => esc_html__( "Color of the button.", "engic-extension" ),
					"group" => esc_html__( "Second Button", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Second Button Text", "engic-extension" ),
					"param_name" => "button2_text",
					"value" => "",
					"description" => esc_html__( "Leave this field empty if you don't want to show this button.", "engic-extension" ),
					"group" => esc_html__( "Second Button", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Second Button Size", "engic-extension" ),
					"param_name" => "button2_size",
					"value" => array(
						esc_html__( "Extra Small", "engic-extension" ) => 'extrasmall',
						esc_html__( "Small", "engic-extension" ) => 'small',
						esc_html__( "Medium", "engic-extension" ) => 'medium',
						esc_html__( "Large", "engic-extension" ) => 'large',
						esc_html__( "Extra Large", "engic-extension" ) => 'extralarge',
					),
					"description" => '',
					"std" => 'medium',
					"admin_label" => true,
					"group" => esc_html__( "Second Button", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Button Shape", "engic-extension" ),
					"param_name" => "button2_shape",
					"value" => array(
						esc_html__( "Square", "engic-extension" ) => 'square',
						esc_html__( "Round", "engic-extension" ) => 'round',
						esc_html__( "Extra Round", "engic-extension" ) => 'extra-round',
					),
					"description" => '',
					"std" => 'square',
					"group" => esc_html__( "Second Button", "engic-extension" ),
				),
				array(
					"type" => "vc_link",
					"heading" => esc_html__( "Second Button Link", "engic-extension" ),
					"param_name" => "button2_link",
					"value" => "",
					"description" => esc_html__( "Enter a link for your button.", "engic-extension" ),
					"group" => esc_html__( "Second Button", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Second Button class name", "engic-extension" ),
					"param_name" => "button2_class",
					"description" => esc_html__( "If you wish to style your button differently, then use this field to add a class name and then refer to it in your css file.", "engic-extension" ),
					"group" => esc_html__( "Second Button", "engic-extension" ),
				),
				engic_ext_vce_add_align(),
				engic_ext_vce_add_animation(),
				engic_ext_vce_add_animation_delay(),
				engic_ext_vce_add_margin_bottom(),
				engic_ext_vce_add_el_class(),
			),
		);
	}
}

if( function_exists( 'vc_lean_map' ) ) {
	vc_lean_map( 'engic_slogan', 'engic_ext_slogan_shortcode_params' );
} else if( function_exists( 'vc_map' ) ) {
	$attributes = engic_ext_slogan_shortcode_params( 'engic_slogan' );
	vc_map( $attributes );
}

//Omit closing PHP tag to avoid accidental whitespace output errors.