<?php
/**
 * Social Shortcode
 */

if( !function_exists( 'engic_ext_social_shortcode' ) ) {

	function engic_ext_social_shortcode( $atts, $content ) {

		$output = $data = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'social_facebook' => '',
					'social_twitter' => '',
					'social_linkedin' => '',
					'social_reddit' => '',
					'likes' => '',
					'animation' => '',
					'align' => 'left',
					'shape_color' => 'primary-1',
					'icon_size' => 'medium',
					'icon_shape' => 'square',
					'shape_type' => 'simple',
					'animation_delay' => '200',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$atts
			)
		);

		if ( !empty( $animation ) ) {
			$animation = 'eut-' . $animation;
		}


		$social_classes = array( 'eut-element', 'eut-social', 'eut-align-' . $align );

		if ( !empty( $animation ) ) {
			array_push( $social_classes, 'eut-animated-item' );
			array_push( $social_classes, $animation);
			$data = ' data-delay="' . esc_attr( $animation_delay ) . '"';
		}
		if ( !empty( $el_class ) ) {
			array_push( $social_classes, $el_class);
		}
		$social_class_string = implode( ' ', $social_classes );

		$social_shape_classes = array();

		array_push( $social_shape_classes, 'eut-' . $icon_size );
		array_push( $social_shape_classes, 'eut-' . $icon_shape );
		array_push( $social_shape_classes, 'eut-' . $shape_type );
		array_push( $social_shape_classes, 'eut-bg-' . $shape_color );

		$social_shape_class_string = implode( ' ', $social_shape_classes );

		$style = engic_ext_vce_build_margin_bottom_style( $margin_bottom );

		$engic_ext_permalink = esc_url( get_permalink() );
		$engic_ext_title = esc_attr( get_the_title() );

		ob_start();

		?>
			<div class="<?php echo esc_attr( $social_class_string ); ?>" style="<?php echo $style; ?>"<?php echo $data; ?>>
				<ul>

					<?php if ( !empty( $social_facebook ) ) { ?>
					<li><a href="<?php echo $engic_ext_permalink; ?>" title="<?php echo $engic_ext_title; ?>" class="<?php echo esc_attr( $social_shape_class_string ); ?> eut-social-share-facebook"><i class="fab fa-facebook"></i></a></li>
					<?php } ?>
					<?php if ( !empty( $social_twitter ) ) { ?>
					<li><a href="<?php echo $engic_ext_permalink; ?>" title="<?php echo $engic_ext_title; ?>" class="<?php echo esc_attr( $social_shape_class_string ); ?> eut-social-share-twitter"><i class="fab fa-x-twitter"></i></a></li>
					<?php } ?>
					<?php if ( !empty( $social_linkedin ) ) { ?>
					<li><a href="<?php echo $engic_ext_permalink; ?>" title="<?php echo $engic_ext_title; ?>" class="<?php echo esc_attr( $social_shape_class_string ); ?> eut-social-share-linkedin"><i class="fab fa-linkedin"></i></a></li>
					<?php } ?>
					<?php if ( !empty( $social_reddit ) ) { ?>
					<li><a href="<?php echo $engic_ext_permalink; ?>" title="<?php echo $engic_ext_title; ?>" class="<?php echo esc_attr( $social_shape_class_string ); ?> eut-social-share-reddit"><i class="fab fa-reddit"></i></a></li>
					<?php } ?>

					<?php if ( !empty( $likes ) && function_exists( 'engic_eutf_likes' ) ) {
						global $post;
						$post_id = $post->ID;
					?>
					<li><a href="#" class="<?php echo esc_attr( $social_shape_class_string ); ?> eut-like-counter-link" data-post-id="<?php echo $post_id; ?>"><i class="fas fa-heart"></i><span class="eut-like-counter"><?php echo engic_eutf_likes( $post_id ); ?></span></a></li>
					<?php } ?>

				</ul>
			</div>
		<?php

		return ob_get_clean();

	}
	add_shortcode( 'engic_social', 'engic_ext_social_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

if( !function_exists( 'engic_ext_social_shortcode_params' ) ) {
	function engic_ext_social_shortcode_params( $tag ) {
		return array(
			"name" => esc_html__( "Social", "engic-extension" ),
			"description" => esc_html__( "Place your preferred social", "engic-extension" ),
			"base" => $tag,
			"class" => "",
			"icon"      => "icon-wpb-eut-social",
			"category" => esc_html__( "Content", "js_composer" ),
			"params" => array(
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Facebook", "engic-extension" ),
					"param_name" => "social_facebook",
					"description" => esc_html__( "Share in Facebook", "engic-extension" ),
					"value" => Array( esc_html__( "Show Facebook social share", "engic-extension" ) => 'yes' ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Twitter", "engic-extension" ),
					"param_name" => "social_twitter",
					"description" => esc_html__( "Share in Twitter", "engic-extension" ),
					"value" => Array( esc_html__( "Show Twitter social share", "engic-extension" ) => 'yes' ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Linkedin", "engic-extension" ),
					"param_name" => "social_linkedin",
					"description" => esc_html__( "Share in Linkedin", "engic-extension" ),
					"value" => Array( esc_html__( "Show Linkedin social share", "engic-extension" ) => 'yes' ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "reddit", "engic-extension" ),
					"param_name" => "social_reddit",
					"description" => esc_html__( "Submit in reddit", "engic-extension" ),
					"value" => Array( esc_html__( "Show reddit social share", "engic-extension" ) => 'yes' ),
				),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "(Euthemians) Likes", "engic-extension" ),
					"param_name" => "likes",
					"description" => esc_html__( "(Euthemians) Likes", "engic-extension" ),
					"value" => Array( esc_html__( "Show (Euthemians) Likes", "engic-extension" ) => 'yes' ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Icon size", "engic-extension" ),
					"param_name" => "icon_size",
					"value" => array(
						esc_html__( "Large", "engic-extension" ) => 'large',
						esc_html__( "Medium", "engic-extension" ) => 'medium',
						esc_html__( "Small", "engic-extension" ) => 'small',
					),
					"std" => 'medium',
					"description" => '',
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Shape Color", "engic-extension" ),
					"param_name" => "shape_color",
					"value" => array(
						esc_html__( "Primary 1", "engic-extension" ) => 'primary-1',
						esc_html__( "Primary 2", "engic-extension" ) => 'primary-2',
						esc_html__( "Primary 3", "engic-extension" ) => 'primary-3',
						esc_html__( "Primary 4", "engic-extension" ) => 'primary-4',
						esc_html__( "Primary 5", "engic-extension" ) => 'primary-5',
					),
					"description" => esc_html__( "Color of the shape.", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Icon shape", "engic-extension" ),
					"param_name" => "icon_shape",
					"value" => array(
						esc_html__( "Square", "engic-extension" ) => 'square',
						esc_html__( "Round", "engic-extension" ) => 'round',
						esc_html__( "Circle", "engic-extension" ) => 'circle',
					),
					"description" => '',
					"admin_label" => true,
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Shape type", "engic-extension" ),
					"param_name" => "shape_type",
					"value" => array(
						esc_html__( "Simple", "engic-extension" ) => 'simple',
						esc_html__( "Outline", "engic-extension" ) => 'outline',
					),
					"description" => esc_html__( "Select shape type.", "engic-extension" ),
				),
				engic_ext_vce_add_align(),
				engic_ext_vce_add_animation(),
				engic_ext_vce_add_animation_delay(),
				engic_ext_vce_add_margin_bottom(),
				engic_ext_vce_add_el_class(),
			),
		);
	}
}

if( function_exists( 'vc_lean_map' ) ) {
	vc_lean_map( 'engic_social', 'engic_ext_social_shortcode_params' );
} else if( function_exists( 'vc_map' ) ) {
	$attributes = engic_ext_social_shortcode_params( 'engic_social' );
	vc_map( $attributes );
}

//Omit closing PHP tag to avoid accidental whitespace output errors.