<?php
/**
 * Team Shortcode
 */

if( !function_exists( 'engic_ext_team_shortcode' ) ) {

	function engic_ext_team_shortcode( $attr, $content ) {

		$output = $data = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'image' => '',
					'image_size' => 'square',
					'name' => '',
					'identity' => '',
					'social_facebook' => '',
					'social_twitter' => '',
					'social_linkedin' => '',
					'align' => 'left',
					'email' => '',
					'link' => '',
					'animation' => '',
					'animation_delay' => '200',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$attr
			)
		);

		if ( !empty( $animation ) ) {
			$animation = 'eut-' . $animation;
		}

		if( 'square' == $image_size ) {
			$image_size = 'engic-eutf-small-square';
		} elseif( 'portrait' == $image_size ) {
			$image_size = 'engic-eutf-small-rect-vertical';
		} elseif ( 'landscape' == $image_size ) {
			$image_size = 'engic-eutf-small-rect-horizontal';
		} else {
			$image_size = 'large';
		}


		$style = engic_ext_vce_build_margin_bottom_style( $margin_bottom );

		if ( !empty( $image ) ) {
			$id = preg_replace('/[^\d]/', '', $image);
			$image_string = wp_get_attachment_image( $id, $image_size );
		} else {
			$image_string = engic_ext_vce_get_empty_image( $image_size );
		}

		if ( !empty( $link ) ){
			$href = vc_build_link( $link );
			$url = $href['url'];
			if ( !empty( $href['target'] ) ){
				$target = $href['target'];
			} else {
				$target = "_self";
			}
		} else {
			$url = "#";
			$target = "_self";
		}
		$target = trim( $target );

		$links = '';
		if ( !empty( $social_facebook ) ) {
			$links .= '<li><a href="' . esc_url( $social_facebook ) . '" target="_blank" rel="noopener noreferrer" class="eut-small-text eut-color-text eut-hover-color-primary-1">Facebook</a></li>';
		}
		if ( !empty( $social_twitter ) ) {
			$links .= '<li><a href="' . esc_url( $social_twitter ) . '" target="_blank" rel="noopener noreferrer" class="eut-small-text eut-color-text eut-hover-color-primary-1">Twitter</a></li>';
		}
		if ( !empty( $social_linkedin ) ) {
			$links .= '<li><a href="' . esc_url( $social_linkedin ) . '" target="_blank" rel="noopener noreferrer" class="eut-small-text eut-color-text eut-hover-color-primary-1">Linkedin</a></li>';
		}
		if ( !empty( $email ) ) {
			$links .= '<li><a href="mailto:' . antispambot( $email ) . '" class="eut-small-text eut-color-text eut-hover-color-primary-1">E-mail</a></li>';
		}

		$team_classes = array( 'eut-element' );

		if ( !empty( $animation ) ) {
			array_push( $team_classes, 'eut-animated-item' );
			array_push( $team_classes, $animation);
			$data = ' data-delay="' . esc_attr( $animation_delay ) . '"';
		}
		if ( !empty( $el_class ) ) {
			array_push( $team_classes, $el_class);
		}

		$team_class_string = implode( ' ', $team_classes );


		ob_start();

		?>

		<div class="eut-team <?php echo esc_attr( $team_class_string ); ?>" style="<?php echo $style; ?>"<?php echo $data; ?>>
			<figure>
				<?php if ( !empty( $url ) && '#' != $url ) { ?>
				<a href="<?php echo esc_url( $url ); ?>" target="<?php echo esc_attr( $target ); ?>">
				<?php } ?>
				<div class="eut-team-person eut-media">
					<?php echo $image_string; ?>
				</div>
				<?php if ( !empty( $url ) && '#' != $url ) { ?>
				</a>
				<?php } ?>
				<figcaption>
					<div class="eut-team-description eut-align-<?php echo esc_attr( $align ); ?>">
						<?php if ( !empty( $url ) && '#' != $url ) { ?>
						<a href="<?php echo esc_url( $url ); ?>" target="<?php echo esc_attr( $target ); ?>">
						<?php } ?>
						<h5 class="eut-team-name"><?php echo esc_html( $name ); ?></h5>
						<?php if ( !empty( $url ) && '#' != $url ) { ?>
						</a>
						<?php } ?>
						<?php if ( !empty( $identity ) ) { ?>
						<div class="eut-team-identity eut-small-text eut-color-primary-1"><?php echo esc_html( $identity ); ?></div>
						<?php } ?>
						<?php if ( !empty( $content ) ) { ?>
						<p class="eut-team-content"><?php echo $content; ?></p>
						<?php } ?>
					</div>
					<?php if ( !empty( $links ) ) { ?>
					<div class="eut-team-social eut-align-<?php echo esc_attr( $align ); ?>">
						<ul>
							<?php echo $links; ?>
						</ul>
					</div>
					<?php } ?>
				</figcaption>
			</figure>
		</div>

		<?php

		return ob_get_clean();

	}
	add_shortcode( 'engic_team', 'engic_ext_team_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

if( !function_exists( 'engic_ext_team_shortcode_params' ) ) {
	function engic_ext_team_shortcode_params( $tag ) {
		return array(
			"name" => esc_html__( "Team", "engic-extension" ),
			"description" => esc_html__( "Show your team members", "engic-extension" ),
			"base" => $tag,
			"class" => "",
			"icon"      => "icon-wpb-eut-team",
			"category" => esc_html__( "Content", "js_composer" ),
			"params" => array(
				array(
					"type" => "attach_image",
					"heading" => esc_html__( "Image", "engic-extension" ),
					"param_name" => "image",
					"value" => '',
					"description" => esc_html__( "Select an image.", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Grid Image Mode", "engic-extension" ),
					"param_name" => "image_size",
					'value' => array(
						esc_html__( 'Square Crop', 'engic-extension' ) => 'square',
						esc_html__( 'Landscape Crop', 'engic-extension' ) => 'landscape',
						esc_html__( 'Portrait Crop', 'engic-extension' ) => 'portrait',
						esc_html__( 'Resize ( Large )', 'engic-extension' ) => 'resize',
					),
					'std' => 'square',
					"description" => esc_html__( "Select your Grid Image Mode.", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Name", "engic-extension" ),
					"param_name" => "name",
					"value" => "John Smith",
					"description" => esc_html__( "Enter your team name.", "engic-extension" ),
					"save_always" => true,
					"admin_label" => true,
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Identity", "engic-extension" ),
					"param_name" => "identity",
					"value" => "",
					"description" => esc_html__( "Enter your team identity/profession e.g: Designer", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Facebook", "engic-extension" ),
					"param_name" => "social_facebook",
					"value" => "",
					"description" => esc_html__( "Enter facebook URL. Clear input if you don't want to display.", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Twitter", "engic-extension" ),
					"param_name" => "social_twitter",
					"value" => "",
					"description" => esc_html__( "Enter twitter URL. Clear input if you don't want to display.", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Linkedin", "engic-extension" ),
					"param_name" => "social_linkedin",
					"value" => "",
					"description" => esc_html__( "Enter linkedin URL. Clear input if you don't want to display.", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Email", "engic-extension" ),
					"param_name" => "email",
					"value" => "",
					"description" => esc_html__( "Enter your email. Clear input if you don't want to display.", "engic-extension" ),
				),
				array(
					"type" => "textarea",
					"heading" => esc_html__( "Text", "engic-extension" ),
					"param_name" => "content",
					"value" => "Sample Text",
					"description" => esc_html__( "Enter your text.", "engic-extension" ),
				),
				array(
					"type" => "vc_link",
					"heading" => esc_html__( "Link", "engic-extension" ),
					"param_name" => "link",
					"value" => "",
					"description" => esc_html__( "Enter link.", "engic-extension" ),
				),
				engic_ext_vce_add_align(),
				engic_ext_vce_add_animation(),
				engic_ext_vce_add_animation_delay(),
				engic_ext_vce_add_margin_bottom(),
				engic_ext_vce_add_el_class(),
			),
		);
	}
}

if( function_exists( 'vc_lean_map' ) ) {
	vc_lean_map( 'engic_team', 'engic_ext_team_shortcode_params' );
} else if( function_exists( 'vc_map' ) ) {
	$attributes = engic_ext_team_shortcode_params( 'engic_team' );
	vc_map( $attributes );
}

//Omit closing PHP tag to avoid accidental whitespace output errors.