<?php
/**
 * Testimonial Shortcode
 */

if( !function_exists( 'engic_ext_testimonial_shortcode' ) ) {

	function engic_ext_testimonial_shortcode( $attr, $content ) {

		$portfolio_row_start = $allow_filter = $class_fullwidth = $slider_data = $output = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'categories' => '',
					'exclude_posts' => '',
					'include_posts' => '',
					'items_to_show' => '20',
					'order_by' => 'date',
					'order' => 'DESC',
					'margin_bottom' => '',
					'slideshow_speed' => '3000',
					'pagination_speed' => '400',
					'auto_play' => 'yes',
					'pause_hover' => 'no',
					'auto_height' => 'no',
					'align' => 'left',
					'text_style' => 'none',
					'el_class' => '',
				),
				$attr
			)
		);

		$testimonial_classes = array( 'eut-element', 'eut-testimonial', 'eut-carousel-element', 'eut-align-' . $align );

		if ( !empty ( $el_class ) ) {
			array_push( $testimonial_classes, $el_class);
		}

		if ( 'none' != $text_style ) {
			$text_style_class = 'eut-' .$text_style;
			array_push( $testimonial_classes, $text_style_class);
		}

		$testimonial_class_string = implode( ' ', $testimonial_classes );

		$style = engic_ext_vce_build_margin_bottom_style( $margin_bottom );

		$slider_data = '';
		$slider_data .= ' data-slider-speed="' . esc_attr( $slideshow_speed ) . '"';
		$slider_data .= ' data-pagination-speed="' . esc_attr( $pagination_speed ) . '"';
		$slider_data .= ' data-slider-autoheight="' . esc_attr( $auto_height ) . '"';
		$slider_data .= ' data-slider-pause="' . esc_attr( $pause_hover ) . '"';
		$slider_data .= ' data-slider-autoplay="' . esc_attr( $auto_play ) . '"';

		$testimonial_cat = "";

		if ( !empty( $categories ) ) {
			$testimonial_category_list = explode( ",", $categories );
			foreach ( $testimonial_category_list as $testimonial_list ) {
				$testimonial_term = get_term( $testimonial_list, 'testimonial_category' );
				$testimonial_cat = $testimonial_cat.$testimonial_term->slug . ', ';
			}
		}
		
		$exclude_ids = array();
		if( !empty( $exclude_posts ) ){
			$exclude_ids = explode( ',', $exclude_posts );
		}

		$include_ids = array();
		if( !empty( $include_posts ) ){
			$include_ids = explode( ',', $include_posts );
			$args = array(
				'post_type' => 'testimonial',
				'post_status'=>'publish',
				'paged' => 1,
				'post__in' => $include_ids,
				'posts_per_page' => $items_to_show,
				'orderby' => $order_by,
				'order' => $order,
			);
		} else {
			$args = array(
				'post_type' => 'testimonial',
				'post_status'=>'publish',
				'paged' => 1,
				'testimonial_category' => $testimonial_cat,
				'post__not_in' => $exclude_ids,
				'posts_per_page' => $items_to_show,
				'orderby' => $order_by,
				'order' => $order,
			);
		}		

		$query = new WP_Query( $args );

		ob_start();

		if ( $query->have_posts() ) :

		?>
			<div class="<?php echo esc_attr( $testimonial_class_string ); ?>" style="<?php echo $style; ?>"<?php echo $slider_data; ?>>

		<?php
		while ( $query->have_posts() ) : $query->the_post();

			$name = get_post_meta( get_the_ID(), '_engic_eutf_testimonial_name', true );
			$identity =  get_post_meta( get_the_ID(), '_engic_eutf_testimonial_identity', true );

			if ( !empty( $name ) && !empty( $identity ) ) {
				$identity = ', ' . $identity;
			}

		?>
				<div class="eut-testimonial-element">
					<?php the_content(); ?>
					<?php if ( !empty( $name ) || !empty( $identity ) ) { ?>
					<div class="eut-testimonial-name"><?php echo esc_html( $name . $identity ); ?></div>
					<?php } ?>
				</div>
		<?php
		endwhile;

		?>
			</div>

		<?php
		else :
		endif;
		wp_reset_postdata();

		return ob_get_clean();

	}
	add_shortcode( 'engic_testimonial', 'engic_ext_testimonial_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

if( !function_exists( 'engic_ext_testimonial_shortcode_params' ) ) {
	function engic_ext_testimonial_shortcode_params( $tag ) {
		return array(
			"name" => esc_html__( "Testimonial", "engic-extension" ),
			"description" => esc_html__( "Add a captivating testimonial slider", "engic-extension" ),
			"base" => $tag,
			"class" => "",
			"icon"      => "icon-wpb-eut-testimonial",
			"category" => esc_html__( "Content", "js_composer" ),
			"params" => array(
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Items to show", "engic-extension" ),
					"param_name" => "items_to_show",
					"value" => '20',
					"description" => esc_html__( "Maximum Testimonial Items to Show", "engic-extension" ),
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Autoplay", "engic-extension" ),
					"param_name" => "auto_play",
					"value" => array(
						esc_html__( "Yes", "engic-extension" ) => 'yes',
						esc_html__( "No", "engic-extension" ) => 'no',
					),
				),
				engic_ext_vce_add_slideshow_speed(),
				engic_ext_vce_add_pagination_speed(),
				array(
					"type" => 'checkbox',
					"heading" => esc_html__( "Pause on Hover", "engic-extension" ),
					"param_name" => "pause_hover",
					"value" => Array( esc_html__( "If selected, testimonial will be paused on hover", "engic-extension" ) => 'yes' ),
				),
				engic_ext_vce_add_auto_height(),
				array(
					"type" => "dropdown",
					"heading" => esc_html__( "Text Style", "engic-extension" ),
					"param_name" => "text_style",
					"value" => array(
						esc_html__( "None", "engic-extension" ) => '',
						esc_html__( "Leader", "engic-extension" ) => 'leader-text',
						esc_html__( "Subtitle", "engic-extension" ) => 'subtitle',
					),
					"description" => 'Select your text style',
				),
				engic_ext_vce_add_align(),
				engic_ext_vce_add_order_by(),
				engic_ext_vce_add_order(),
				engic_ext_vce_add_margin_bottom(),
				engic_ext_vce_add_el_class(),
				array(
					"type" => "textfield",
					"heading" => esc_html__("Exclude Posts", "engic-extension" ),
					"param_name" => "exclude_posts",
					"value" => '',
					"description" => esc_html__( "Type the post ids you want to exclude separated by comma ( , ).", "engic-extension" ),
					"group" => esc_html__( "Categories", "engic-extension" ),
				),
				array(
					"type" => "engic_ext_multi_checkbox",
					"heading" => esc_html__("Testimonial Categories", "engic-extension" ),
					"param_name" => "categories",
					"value" => engic_ext_vce_get_testimonial_categories(),
					"description" => esc_html__( "Select all or multiple categories.", "engic-extension" ),
					"admin_label" => true,
					"group" => esc_html__( "Categories", "engic-extension" ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__("Include Specific Posts", "engic-extension" ),
					"param_name" => "include_posts",
					"value" => '',
					"description" => esc_html__( "Type the specific post ids you want to include separated by comma ( , ). Note: If you define specific post ids, Exclude Posts and Categories will have no effect.", "engic-extension" ),
					"group" => esc_html__( "Categories", "engic-extension" ),
				),
			)
		);
	}
}

if( function_exists( 'vc_lean_map' ) ) {
	vc_lean_map( 'engic_testimonial', 'engic_ext_testimonial_shortcode_params' );
} else if( function_exists( 'vc_map' ) ) {
	$attributes = engic_ext_testimonial_shortcode_params( 'engic_testimonial' );
	vc_map( $attributes );
}

//Omit closing PHP tag to avoid accidental whitespace output errors.