<?php
/**
 * Euthemians Social Networking
 * A widget that displays social networking links.
 * @author		Euthemians Team
 * @URI			http://euthemians.com
 */

class Engic_Ext_Widget_Social extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'classname' => 'eut-widget eut-social',
			'description' => esc_html__( 'A widget that displays social networking links', 'engic-extension' ),
		);
		$control_ops = array(
			'width' => 400,
			'height' => 600,
			'id_base' => 'eut-widget-social',
		);
		parent::__construct( 'eut-widget-social', '(Euthemians) ' . esc_html__( 'Social Networking', 'engic-extension' ), $widget_ops, $control_ops );
	}

	function engic_ext_widget_social() {
		$this->__construct();
	}

	function widget( $args, $instance ) {

		global $engic_eutf_social_list_extended;

		extract( $args );

		//Our variables from the widget settings.
		$title = apply_filters( 'widget_title', $instance['title'] );

		echo $before_widget; // XSS OK

		// Display the widget title
		if ( $title ) {
			echo $before_title . esc_html( $title ) . $after_title; // XSS OK
		}
	?>

		<ul>
		<?php

		$icon_size = engic_ext_vce_array_value( $instance, 'icon_size' );
		$shape = engic_ext_vce_array_value( $instance, 'shape' );
		$shape_type = engic_ext_vce_array_value( $instance, 'shape_type' );

		$social_shape_classes = array();

		array_push( $social_shape_classes, 'eut-' . $icon_size );
		if ( !empty( $shape ) ) {
			array_push( $social_shape_classes, 'eut-' . $shape );
			array_push( $social_shape_classes, 'eut-' . $shape_type );
		}

		$social_shape_class_string = implode( ' ', $social_shape_classes );
		if ( isset( $engic_eutf_social_list_extended ) ) {
			foreach ( $engic_eutf_social_list_extended as $social_item ) {

				$social_item_url = engic_ext_vce_array_value( $instance, $social_item['url'] );
				if ( ! empty( $social_item_url ) ) {

					if ( 'skype' == $social_item['id'] ) {
		?>
					<li>
						<a href="<?php echo esc_url( $social_item_url, array( 'skype', 'http', 'https' ) ); ?>" class="<?php echo esc_attr( $social_shape_class_string ); ?> <?php echo esc_attr( $social_item['class'] ); ?>" aria-label="<?php echo esc_attr( $social_item['title'] ); ?>"></a>
					</li>
		<?php
					} else {
		?>
					<li>
						<a href="<?php echo esc_url( $social_item_url ); ?>" class="<?php echo esc_attr( $social_shape_class_string ); ?> <?php echo esc_attr( $social_item['class'] ); ?>" target="_blank" rel="noopener noreferrer" aria-label="<?php echo esc_attr( $social_item['title'] ); ?>"></a>
					</li>
		<?php
					}
				}
			}
		}
		?>
		</ul>


	<?php

		echo $after_widget; // XSS OK
	}

	//Update the widget

	function update( $new_instance, $old_instance ) {

		global $engic_eutf_social_list_extended;

		$instance = $old_instance;
		//Strip tags from title to remove HTML
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['icon_size'] = strip_tags( $new_instance['icon_size'] );
		$instance['shape'] = strip_tags( $new_instance['shape'] );
		$instance['shape_type'] = strip_tags( $new_instance['shape_type'] );
		if ( isset( $engic_eutf_social_list_extended ) ) {
			foreach ( $engic_eutf_social_list_extended as $social_item ) {
				$instance[ $social_item['url'] ] = strip_tags( $new_instance[ $social_item['url'] ] );
			}
		}

		return $instance;
	}


	function form( $instance ) {

		global $engic_eutf_social_list_extended;

		//Set up some default widget settings.
		$defaults = array(
			'title' => '',
			'icon_size' => 'medium',
			'shape' => 'square',
			'shape_type' => 'outline',
		);

		$instance = wp_parse_args( (array) $instance, $defaults );

		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php echo esc_html__( 'Title:', 'engic-extension' ); ?></label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" style="width:100%;" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'icon_size' ) ); ?>"><?php echo esc_html__( 'Icon Size:', 'engic-extension' ); ?></label>
			<select name="<?php echo esc_attr( $this->get_field_name( 'icon_size' ) ); ?>" style="width:100%;">
				<option value="large" <?php selected( "large", engic_ext_vce_array_value( $instance, 'icon_size' ) ); ?>><?php echo esc_html__( "Large", 'engic-extension' ); ?></option>
				<option value="medium" <?php selected( "medium", engic_ext_vce_array_value( $instance, 'icon_size' ) ); ?>><?php echo esc_html__( "Medium", 'engic-extension' ); ?></option>
				<option value="small" <?php selected( "small", engic_ext_vce_array_value( $instance, 'icon_size' ) ); ?>><?php echo esc_html__( "Small", 'engic-extension' ); ?></option>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'shape' ) ); ?>"><?php echo esc_html__( 'Shape:', 'engic-extension' ); ?></label>
			<select  name="<?php echo esc_attr( $this->get_field_name( 'shape' ) ); ?>" style="width:100%;">
				<option value="square" <?php selected( "square", engic_ext_vce_array_value( $instance, 'shape' ) ); ?>><?php echo esc_html__( "Square", 'engic-extension' ); ?></option>
				<option value="round" <?php selected( "round", engic_ext_vce_array_value( $instance, 'shape' ) ); ?>><?php echo esc_html__( "Round", 'engic-extension' ); ?></option>
				<option value="circle" <?php selected( "circle", engic_ext_vce_array_value( $instance, 'shape' ) ); ?>><?php echo esc_html__( "Circle", 'engic-extension' ); ?></option>
				<option value="" <?php selected( "", engic_ext_vce_array_value( $instance, 'shape' ) ); ?>><?php echo esc_html__( "None", 'engic-extension' ); ?></option>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'shape_type' ) ); ?>"><?php echo esc_html__( 'Shape Type:', 'engic-extension' ); ?></label>
			<select  name="<?php echo esc_attr( $this->get_field_name( 'shape_type' ) ); ?>" style="width:100%;">
				<option value="simple" <?php selected( "simple", engic_ext_vce_array_value( $instance, 'shape_type' ) ); ?>><?php echo esc_html__( "Simple", 'engic-extension' ); ?></option>
				<option value="outline" <?php selected( "outline", engic_ext_vce_array_value( $instance, 'shape_type' ) ); ?>><?php echo esc_html__( "Outline", 'engic-extension' ); ?></option>
			</select>
		</p>
		<p>
			<em><?php echo esc_html__( 'Note: Make sure you include the full URL (i.e. http://www.samplesite.com)', 'engic-extension' ); ?></em>
			<br>
			 <?php echo esc_html__( 'If you do not want a social to be visible, simply delete the supplied URL.', 'engic-extension' ); ?>
		</p>

		<?php
		if ( isset( $engic_eutf_social_list_extended ) ) {
			foreach ( $engic_eutf_social_list_extended as $social_item ) {

				$social_item_url = engic_ext_vce_array_value( $instance, $social_item['url'] );
		?>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( $social_item['url'] ) ); ?>"><?php echo esc_html( $social_item['title'] ); ?>:</label>
				<input style="width: 100%;" id="<?php echo esc_attr( $this->get_field_id( $social_item['url'] ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( $social_item['url'] ) ); ?>" value="<?php echo esc_attr( $social_item_url ); ?>" />
			</p>

		<?php
			}
		}
		?>

	<?php
	}
}

//Omit closing PHP tag to avoid accidental whitespace output errors.
